/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtMultimediaAPI_H
#define _QtMultimediaAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtMultimedia[0]
#define sipNameNr_QMediaPlayer__PitchCompensationAvailability 45
#define sipName_QMediaPlayer__PitchCompensationAvailability &sipStrings_QtMultimedia[45]
#define sipNameNr_QVideoFrame__PaintOptions__PaintFlag 89
#define sipName_QVideoFrame__PaintOptions__PaintFlag &sipStrings_QtMultimedia[89]
#define sipNameNr_defaultChannelConfigForChannelCount 126
#define sipName_defaultChannelConfigForChannelCount &sipStrings_QtMultimedia[126]
#define sipNameNr_QAudioFormat__AudioChannelPosition 162
#define sipName_QAudioFormat__AudioChannelPosition &sipStrings_QtMultimedia[162]
#define sipNameNr_QVideoFrameFormat__YCbCrColorSpace 197
#define sipName_QVideoFrameFormat__YCbCrColorSpace &sipStrings_QtMultimedia[197]
#define sipNameNr_232 232
#define sipName_232 &sipStrings_QtMultimedia[232]
#define sipNameNr_266 266
#define sipName_266 &sipStrings_QtMultimedia[266]
#define sipNameNr_299 299
#define sipName_299 &sipStrings_QtMultimedia[299]
#define sipNameNr_QPlaybackOptions__PlaybackIntent 332
#define sipName_QPlaybackOptions__PlaybackIntent &sipStrings_QtMultimedia[332]
#define sipNameNr_QVideoFrameFormat__ColorTransfer 365
#define sipName_QVideoFrameFormat__ColorTransfer &sipStrings_QtMultimedia[365]
#define sipNameNr_398 398
#define sipName_398 &sipStrings_QtMultimedia[398]
#define sipNameNr_430 430
#define sipName_430 &sipStrings_QtMultimedia[430]
#define sipNameNr_462 462
#define sipName_462 &sipStrings_QtMultimedia[462]
#define sipNameNr_QVideoFrameFormat__PixelFormat 494
#define sipName_QVideoFrameFormat__PixelFormat &sipStrings_QtMultimedia[494]
#define sipNameNr_Format_ARGB8888_Premultiplied 525
#define sipName_Format_ARGB8888_Premultiplied &sipStrings_QtMultimedia[525]
#define sipNameNr_Format_BGRA8888_Premultiplied 555
#define sipName_Format_BGRA8888_Premultiplied &sipStrings_QtMultimedia[555]
#define sipNameNr_PitchCompensationAvailability 59
#define sipName_PitchCompensationAvailability &sipStrings_QtMultimedia[59]
#define sipNameNr_QMediaRecorder__RecorderState 585
#define sipName_QMediaRecorder__RecorderState &sipStrings_QtMultimedia[585]
#define sipNameNr_QVideoFrameFormat__ColorRange 615
#define sipName_QVideoFrameFormat__ColorRange &sipStrings_QtMultimedia[615]
#define sipNameNr_QVideoFrameFormat__ColorSpace 645
#define sipName_QVideoFrameFormat__ColorSpace &sipStrings_QtMultimedia[645]
#define sipNameNr_pitchCompensationAvailability 675
#define sipName_pitchCompensationAvailability &sipStrings_QtMultimedia[675]
#define sipNameNr_QMediaFormat__ConversionMode 705
#define sipName_QMediaFormat__ConversionMode &sipStrings_QtMultimedia[705]
#define sipNameNr_QMediaRecorder__EncodingMode 734
#define sipName_QMediaRecorder__EncodingMode &sipStrings_QtMultimedia[734]
#define sipNameNr_QVideoFrameFormat__Direction 763
#define sipName_QVideoFrameFormat__Direction &sipStrings_QtMultimedia[763]
#define sipNameNr_QAudioFormat__ChannelConfig 792
#define sipName_QAudioFormat__ChannelConfig &sipStrings_QtMultimedia[792]
#define sipNameNr_QMediaPlayer__PlaybackState 820
#define sipName_QMediaPlayer__PlaybackState &sipStrings_QtMultimedia[820]
#define sipNameNr_exposureCompensationChanged 848
#define sipName_exposureCompensationChanged &sipStrings_QtMultimedia[848]
#define sipNameNr_isWhiteBalanceModeSupported 876
#define sipName_isWhiteBalanceModeSupported &sipStrings_QtMultimedia[876]
#define sipNameNr_manualIsoSensitivityChanged 904
#define sipName_manualIsoSensitivityChanged &sipStrings_QtMultimedia[904]
#define sipNameNr_ChannelConfigSurround5Dot0 932
#define sipName_ChannelConfigSurround5Dot0 &sipStrings_QtMultimedia[932]
#define sipNameNr_ChannelConfigSurround5Dot1 959
#define sipName_ChannelConfigSurround5Dot1 &sipStrings_QtMultimedia[959]
#define sipNameNr_ChannelConfigSurround7Dot0 986
#define sipName_ChannelConfigSurround7Dot0 &sipStrings_QtMultimedia[986]
#define sipNameNr_ChannelConfigSurround7Dot1 1013
#define sipName_ChannelConfigSurround7Dot1 &sipStrings_QtMultimedia[1013]
#define sipNameNr_QAudioFormat__SampleFormat 1040
#define sipName_QAudioFormat__SampleFormat &sipStrings_QtMultimedia[1040]
#define sipNameNr_1067 1067
#define sipName_1067 &sipStrings_QtMultimedia[1067]
#define sipNameNr_QMediaFormat__ResolveFlags 1094
#define sipName_QMediaFormat__ResolveFlags &sipStrings_QtMultimedia[1094]
#define sipNameNr_QVideoFrame__RotationAngle 1121
#define sipName_QVideoFrame__RotationAngle &sipStrings_QtMultimedia[1121]
#define sipNameNr_imageFormatFromPixelFormat 1148
#define sipName_imageFormatFromPixelFormat &sipStrings_QtMultimedia[1148]
#define sipNameNr_pixelFormatFromImageFormat 1175
#define sipName_pixelFormatFromImageFormat &sipStrings_QtMultimedia[1175]
#define sipNameNr_Format_AYUV_Premultiplied 1202
#define sipName_Format_AYUV_Premultiplied &sipStrings_QtMultimedia[1202]
#define sipNameNr_Format_SamplerExternalOES 1228
#define sipName_Format_SamplerExternalOES &sipStrings_QtMultimedia[1228]
#define sipNameNr_QCamera__WhiteBalanceMode 1254
#define sipName_QCamera__WhiteBalanceMode &sipStrings_QtMultimedia[1254]
#define sipNameNr_QImageCapture__FileFormat 1280
#define sipName_QImageCapture__FileFormat &sipStrings_QtMultimedia[1280]
#define sipNameNr_QMediaPlayer__MediaStatus 1306
#define sipName_QMediaPlayer__MediaStatus &sipStrings_QtMultimedia[1306]
#define sipNameNr_QMediaTimeRange__Interval 1332
#define sipName_QMediaTimeRange__Interval &sipStrings_QtMultimedia[1332]
#define sipNameNr_QVideoFrame__PaintOptions 1358
#define sipName_QVideoFrame__PaintOptions &sipStrings_QtMultimedia[1358]
#define sipNameNr_manualExposureTimeChanged 1384
#define sipName_manualExposureTimeChanged &sipStrings_QtMultimedia[1384]
#define sipNameNr_NotSupportedFeatureError 1410
#define sipName_NotSupportedFeatureError &sipStrings_QtMultimedia[1410]
#define sipNameNr_1435 1435
#define sipName_1435 &sipStrings_QtMultimedia[1435]
#define sipNameNr_1460 1460
#define sipName_1460 &sipStrings_QtMultimedia[1460]
#define sipNameNr_QMediaFormat__AudioCodec 1485
#define sipName_QMediaFormat__AudioCodec &sipStrings_QtMultimedia[1485]
#define sipNameNr_QMediaFormat__FileFormat 1510
#define sipName_QMediaFormat__FileFormat &sipStrings_QtMultimedia[1510]
#define sipNameNr_QMediaFormat__VideoCodec 1535
#define sipName_QMediaFormat__VideoCodec &sipStrings_QtMultimedia[1535]
#define sipNameNr_audioBufferOutputChanged 1560
#define sipName_audioBufferOutputChanged &sipStrings_QtMultimedia[1560]
#define sipNameNr_audioChannelCountChanged 1585
#define sipName_audioChannelCountChanged &sipStrings_QtMultimedia[1585]
#define sipNameNr_maximumZoomFactorChanged 1610
#define sipName_maximumZoomFactorChanged &sipStrings_QtMultimedia[1610]
#define sipNameNr_minimumZoomFactorChanged 1635
#define sipName_minimumZoomFactorChanged &sipStrings_QtMultimedia[1635]
#define sipNameNr_pitchCompensationChanged 1660
#define sipName_pitchCompensationChanged &sipStrings_QtMultimedia[1660]
#define sipNameNr_supportedFeaturesChanged 1685
#define sipName_supportedFeaturesChanged &sipStrings_QtMultimedia[1685]
#define sipNameNr_ConstantBitRateEncoding 1710
#define sipName_ConstantBitRateEncoding &sipStrings_QtMultimedia[1710]
#define sipNameNr_ConstantQualityEncoding 1734
#define sipName_ConstantQualityEncoding &sipStrings_QtMultimedia[1734]
#define sipNameNr_PyQt6_sip_simplewrapper 1758
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtMultimedia[1758]
#define sipNameNr_QCameraDevice__Position 1782
#define sipName_QCameraDevice__Position &sipStrings_QtMultimedia[1782]
#define sipNameNr_QMediaRecorder__Quality 1806
#define sipName_QMediaRecorder__Quality &sipStrings_QtMultimedia[1806]
#define sipNameNr_QVideoFrame__HandleType 1830
#define sipName_QVideoFrame__HandleType &sipStrings_QtMultimedia[1830]
#define sipNameNr_WhiteBalanceFluorescent 1854
#define sipName_WhiteBalanceFluorescent &sipStrings_QtMultimedia[1854]
#define sipNameNr_audioBufferInputChanged 1878
#define sipName_audioBufferInputChanged &sipStrings_QtMultimedia[1878]
#define sipNameNr_colorTemperatureChanged 1902
#define sipName_colorTemperatureChanged &sipStrings_QtMultimedia[1902]
#define sipNameNr_customFocusPointChanged 1926
#define sipName_customFocusPointChanged &sipStrings_QtMultimedia[1926]
#define sipNameNr_isExposureModeSupported 1950
#define sipName_isExposureModeSupported &sipStrings_QtMultimedia[1950]
#define sipNameNr_setExposureCompensation 1974
#define sipName_setExposureCompensation &sipStrings_QtMultimedia[1974]
#define sipNameNr_setManualIsoSensitivity 1998
#define sipName_setManualIsoSensitivity &sipStrings_QtMultimedia[1998]
#define sipNameNr_whiteBalanceModeChanged 2022
#define sipName_whiteBalanceModeChanged &sipStrings_QtMultimedia[2022]
#define sipNameNr_AverageBitRateEncoding 2046
#define sipName_AverageBitRateEncoding &sipStrings_QtMultimedia[2046]
#define sipNameNr_LogarithmicVolumeScale 2069
#define sipName_LogarithmicVolumeScale &sipStrings_QtMultimedia[2069]
#define sipNameNr_QImageCapture__Quality 2092
#define sipName_QImageCapture__Quality &sipStrings_QtMultimedia[2092]
#define sipNameNr_audioSampleRateChanged 2115
#define sipName_audioSampleRateChanged &sipStrings_QtMultimedia[2115]
#define sipNameNr_bufferAvailableChanged 2138
#define sipName_bufferAvailableChanged &sipStrings_QtMultimedia[2138]
#define sipNameNr_playbackOptionsChanged 2161
#define sipName_playbackOptionsChanged &sipStrings_QtMultimedia[2161]
#define sipNameNr_readyForCaptureChanged 2184
#define sipName_readyForCaptureChanged &sipStrings_QtMultimedia[2184]
#define sipNameNr_readyToSendAudioBuffer 2207
#define sipName_readyToSendAudioBuffer &sipStrings_QtMultimedia[2207]
#define sipNameNr_setActiveSubtitleTrack 2230
#define sipName_setActiveSubtitleTrack &sipStrings_QtMultimedia[2230]
#define sipNameNr_supportedSampleFormats 2253
#define sipName_supportedSampleFormats &sipStrings_QtMultimedia[2253]
#define sipNameNr_videoFrameInputChanged 2276
#define sipName_videoFrameInputChanged &sipStrings_QtMultimedia[2276]
#define sipNameNr_videoResolutionChanged 2299
#define sipName_videoResolutionChanged &sipStrings_QtMultimedia[2299]
#define sipNameNr_CapturingNotSupported 2322
#define sipName_CapturingNotSupported &sipStrings_QtMultimedia[2322]
#define sipNameNr_ColorTransfer_Gamma22 2344
#define sipName_ColorTransfer_Gamma22 &sipStrings_QtMultimedia[2344]
#define sipNameNr_ColorTransfer_Gamma28 2366
#define sipName_ColorTransfer_Gamma28 &sipStrings_QtMultimedia[2366]
#define sipNameNr_ColorTransfer_STD_B67 2388
#define sipName_ColorTransfer_STD_B67 &sipStrings_QtMultimedia[2388]
#define sipNameNr_ColorTransfer_Unknown 2410
#define sipName_ColorTransfer_Unknown &sipStrings_QtMultimedia[2410]
#define sipNameNr_ExposureNightPortrait 2432
#define sipName_ExposureNightPortrait &sipStrings_QtMultimedia[2432]
#define sipNameNr_QCamera__ExposureMode 2454
#define sipName_QCamera__ExposureMode &sipStrings_QtMultimedia[2454]
#define sipNameNr_2476 2476
#define sipName_2476 &sipStrings_QtMultimedia[2476]
#define sipNameNr_QMediaRecorder__Error 2498
#define sipName_QMediaRecorder__Error &sipStrings_QtMultimedia[2498]
#define sipNameNr_QScreenCapture__Error 2520
#define sipName_QScreenCapture__Error &sipStrings_QtMultimedia[2520]
#define sipNameNr_QWindowCapture__Error 2542
#define sipName_QWindowCapture__Error &sipStrings_QtMultimedia[2542]
#define sipNameNr_actualLocationChanged 2564
#define sipName_actualLocationChanged &sipStrings_QtMultimedia[2564]
#define sipNameNr_audioCodecDescription 2586
#define sipName_audioCodecDescription &sipStrings_QtMultimedia[2586]
#define sipNameNr_bufferProgressChanged 2608
#define sipName_bufferProgressChanged &sipStrings_QtMultimedia[2608]
#define sipNameNr_fileFormatDescription 2630
#define sipName_fileFormatDescription &sipStrings_QtMultimedia[2630]
#define sipNameNr_isoSensitivityChanged 2652
#define sipName_isoSensitivityChanged &sipStrings_QtMultimedia[2652]
#define sipNameNr_loopsRemainingChanged 2674
#define sipName_loopsRemainingChanged &sipStrings_QtMultimedia[2674]
#define sipNameNr_maximumIsoSensitivity 2696
#define sipName_maximumIsoSensitivity &sipStrings_QtMultimedia[2696]
#define sipNameNr_minimumIsoSensitivity 2718
#define sipName_minimumIsoSensitivity &sipStrings_QtMultimedia[2718]
#define sipNameNr_normalizedSampleValue 2740
#define sipName_normalizedSampleValue &sipStrings_QtMultimedia[2740]
#define sipNameNr_readyToSendVideoFrame 2762
#define sipName_readyToSendVideoFrame &sipStrings_QtMultimedia[2762]
#define sipNameNr_setAutoIsoSensitivity 2784
#define sipName_setAutoIsoSensitivity &sipStrings_QtMultimedia[2784]
#define sipNameNr_setManualExposureTime 2806
#define sipName_setManualExposureTime &sipStrings_QtMultimedia[2806]
#define sipNameNr_videoCodecDescription 2828
#define sipName_videoCodecDescription &sipStrings_QtMultimedia[2828]
#define sipNameNr_videoFrameRateChanged 2850
#define sipName_videoFrameRateChanged &sipStrings_QtMultimedia[2850]
#define sipNameNr_AudioChannelPosition 176
#define sipName_AudioChannelPosition &sipStrings_QtMultimedia[176]
#define sipNameNr_ChannelConfigUnknown 2872
#define sipName_ChannelConfigUnknown &sipStrings_QtMultimedia[2872]
#define sipNameNr_ColorSpace_Undefined 2893
#define sipName_ColorSpace_Undefined &sipStrings_QtMultimedia[2893]
#define sipNameNr_ColorTransfer_Linear 2914
#define sipName_ColorTransfer_Linear &sipStrings_QtMultimedia[2914]
#define sipNameNr_ColorTransfer_ST2084 2935
#define sipName_ColorTransfer_ST2084 &sipStrings_QtMultimedia[2935]
#define sipNameNr_ExposureCompensation 1977
#define sipName_ExposureCompensation &sipStrings_QtMultimedia[1977]
#define sipNameNr_QAudioDecoder__Error 2956
#define sipName_QAudioDecoder__Error &sipStrings_QtMultimedia[2956]
#define sipNameNr_QImageCapture__Error 2977
#define sipName_QImageCapture__Error &sipStrings_QtMultimedia[2977]
#define sipNameNr_2998 2998
#define sipName_2998 &sipStrings_QtMultimedia[2998]
#define sipNameNr_3019 3019
#define sipName_3019 &sipStrings_QtMultimedia[3019]
#define sipNameNr_QMediaCaptureSession 3040
#define sipName_QMediaCaptureSession &sipStrings_QtMultimedia[3040]
#define sipNameNr_QSoundEffect__Status 3061
#define sipName_QSoundEffect__Status &sipStrings_QtMultimedia[3061]
#define sipNameNr_QVideoFrame__MapMode 3082
#define sipName_QVideoFrame__MapMode &sipStrings_QtMultimedia[3082]
#define sipNameNr_WhiteBalanceSunlight 3103
#define sipName_WhiteBalanceSunlight &sipStrings_QtMultimedia[3103]
#define sipNameNr_WhiteBalanceTungsten 3124
#define sipName_WhiteBalanceTungsten &sipStrings_QtMultimedia[3124]
#define sipNameNr_channelConfiguration 3145
#define sipName_channelConfiguration &sipStrings_QtMultimedia[3145]
#define sipNameNr_exposureCompensation 3166
#define sipName_exposureCompensation &sipStrings_QtMultimedia[3166]
#define sipNameNr_focusDistanceChanged 3187
#define sipName_focusDistanceChanged &sipStrings_QtMultimedia[3187]
#define sipNameNr_isFlashModeSupported 3208
#define sipName_isFlashModeSupported &sipStrings_QtMultimedia[3208]
#define sipNameNr_isFocusModeSupported 3229
#define sipName_isFocusModeSupported &sipStrings_QtMultimedia[3229]
#define sipNameNr_isTorchModeSupported 3250
#define sipName_isTorchModeSupported &sipStrings_QtMultimedia[3250]
#define sipNameNr_manualIsoSensitivity 3271
#define sipName_manualIsoSensitivity &sipStrings_QtMultimedia[3271]
#define sipNameNr_playbackStateChanged 3292
#define sipName_playbackStateChanged &sipStrings_QtMultimedia[3292]
#define sipNameNr_recorderStateChanged 3313
#define sipName_recorderStateChanged &sipStrings_QtMultimedia[3313]
#define sipNameNr_resetPlaybackOptions 3334
#define sipName_resetPlaybackOptions &sipStrings_QtMultimedia[3334]
#define sipNameNr_screenCaptureChanged 3355
#define sipName_screenCaptureChanged &sipStrings_QtMultimedia[3355]
#define sipNameNr_setAudioBufferOutput 3376
#define sipName_setAudioBufferOutput &sipStrings_QtMultimedia[3376]
#define sipNameNr_setAudioChannelCount 3397
#define sipName_setAudioChannelCount &sipStrings_QtMultimedia[3397]
#define sipNameNr_setPitchCompensation 3418
#define sipName_setPitchCompensation &sipStrings_QtMultimedia[3418]
#define sipNameNr_setScanLineDirection 3439
#define sipName_setScanLineDirection &sipStrings_QtMultimedia[3439]
#define sipNameNr_supportedAudioCodecs 3460
#define sipName_supportedAudioCodecs &sipStrings_QtMultimedia[3460]
#define sipNameNr_supportedFileFormats 3481
#define sipName_supportedFileFormats &sipStrings_QtMultimedia[3481]
#define sipNameNr_supportedVideoCodecs 3502
#define sipName_supportedVideoCodecs &sipStrings_QtMultimedia[3502]
#define sipNameNr_windowCaptureChanged 3523
#define sipName_windowCaptureChanged &sipStrings_QtMultimedia[3523]
#define sipNameNr_ChannelConfigStereo 3544
#define sipName_ChannelConfigStereo &sipStrings_QtMultimedia[3544]
#define sipNameNr_ColorSpace_AdobeRgb 3564
#define sipName_ColorSpace_AdobeRgb &sipStrings_QtMultimedia[3564]
#define sipNameNr_ColorTransfer_BT601 3584
#define sipName_ColorTransfer_BT601 &sipStrings_QtMultimedia[3584]
#define sipNameNr_ColorTransfer_BT709 3604
#define sipName_ColorTransfer_BT709 &sipStrings_QtMultimedia[3604]
#define sipNameNr_ExposureCandlelight 3624
#define sipName_ExposureCandlelight &sipStrings_QtMultimedia[3624]
#define sipNameNr_ExposureSteadyPhoto 3644
#define sipName_ExposureSteadyPhoto &sipStrings_QtMultimedia[3644]
#define sipNameNr_FocusModeHyperfocal 3664
#define sipName_FocusModeHyperfocal &sipStrings_QtMultimedia[3664]
#define sipNameNr_LocationNotWritable 3684
#define sipName_LocationNotWritable &sipStrings_QtMultimedia[3684]
#define sipNameNr_LowLatencyStreaming 3704
#define sipName_LowLatencyStreaming &sipStrings_QtMultimedia[3704]
#define sipNameNr_QAudio__VolumeScale 3724
#define sipName_QAudio__VolumeScale &sipStrings_QtMultimedia[3724]
#define sipNameNr_3744 3744
#define sipName_3744 &sipStrings_QtMultimedia[3744]
#define sipNameNr_QMediaMetaData__Key 3764
#define sipName_QMediaMetaData__Key &sipStrings_QtMultimedia[3764]
#define sipNameNr_QMediaPlayer__Error 3784
#define sipName_QMediaPlayer__Error &sipStrings_QtMultimedia[3784]
#define sipNameNr_QMediaPlayer__Loops 3804
#define sipName_QMediaPlayer__Loops &sipStrings_QtMultimedia[3804]
#define sipNameNr_UnspecifiedPosition 3824
#define sipName_UnspecifiedPosition &sipStrings_QtMultimedia[3824]
#define sipNameNr_activeSubtitleTrack 3844
#define sipName_activeSubtitleTrack &sipStrings_QtMultimedia[3844]
#define sipNameNr_activeTracksChanged 3864
#define sipName_activeTracksChanged &sipStrings_QtMultimedia[3864]
#define sipNameNr_audioBitRateChanged 3884
#define sipName_audioBitRateChanged &sipStrings_QtMultimedia[3884]
#define sipNameNr_audioBufferReceived 3904
#define sipName_audioBufferReceived &sipStrings_QtMultimedia[3904]
#define sipNameNr_audioOutputsChanged 3924
#define sipName_audioOutputsChanged &sipStrings_QtMultimedia[3924]
#define sipNameNr_cameraDeviceChanged 3944
#define sipName_cameraDeviceChanged &sipStrings_QtMultimedia[3944]
#define sipNameNr_cameraFormatChanged 3964
#define sipName_cameraFormatChanged &sipStrings_QtMultimedia[3964]
#define sipNameNr_encodingModeChanged 3984
#define sipName_encodingModeChanged &sipStrings_QtMultimedia[3984]
#define sipNameNr_exposureModeChanged 4004
#define sipName_exposureModeChanged &sipStrings_QtMultimedia[4004]
#define sipNameNr_exposureTimeChanged 4024
#define sipName_exposureTimeChanged &sipStrings_QtMultimedia[4024]
#define sipNameNr_imageCaptureChanged 4044
#define sipName_imageCaptureChanged &sipStrings_QtMultimedia[4044]
#define sipNameNr_maximumChannelCount 4064
#define sipName_maximumChannelCount &sipStrings_QtMultimedia[4064]
#define sipNameNr_maximumExposureTime 4084
#define sipName_maximumExposureTime &sipStrings_QtMultimedia[4084]
#define sipNameNr_metaDataKeyToString 4104
#define sipName_metaDataKeyToString &sipStrings_QtMultimedia[4104]
#define sipNameNr_minimumChannelCount 4124
#define sipName_minimumChannelCount &sipStrings_QtMultimedia[4124]
#define sipNameNr_minimumExposureTime 4144
#define sipName_minimumExposureTime &sipStrings_QtMultimedia[4144]
#define sipNameNr_pixelFormatToString 4164
#define sipName_pixelFormatToString &sipStrings_QtMultimedia[4164]
#define sipNameNr_playbackRateChanged 4184
#define sipName_playbackRateChanged &sipStrings_QtMultimedia[4184]
#define sipNameNr_resetNetworkTimeout 4204
#define sipName_resetNetworkTimeout &sipStrings_QtMultimedia[4204]
#define sipNameNr_resetPlaybackIntent 4224
#define sipName_resetPlaybackIntent &sipStrings_QtMultimedia[4224]
#define sipNameNr_setActiveAudioTrack 4244
#define sipName_setActiveAudioTrack &sipStrings_QtMultimedia[4244]
#define sipNameNr_setActiveVideoTrack 4264
#define sipName_setActiveVideoTrack &sipStrings_QtMultimedia[4264]
#define sipNameNr_setAudioBufferInput 4284
#define sipName_setAudioBufferInput &sipStrings_QtMultimedia[4284]
#define sipNameNr_setAutoExposureTime 4304
#define sipName_setAutoExposureTime &sipStrings_QtMultimedia[4304]
#define sipNameNr_setBufferFrameCount 4324
#define sipName_setBufferFrameCount &sipStrings_QtMultimedia[4324]
#define sipNameNr_setColorTemperature 4344
#define sipName_setColorTemperature &sipStrings_QtMultimedia[4344]
#define sipNameNr_setCustomFocusPoint 4364
#define sipName_setCustomFocusPoint &sipStrings_QtMultimedia[4364]
#define sipNameNr_setWhiteBalanceMode 4384
#define sipName_setWhiteBalanceMode &sipStrings_QtMultimedia[4384]
#define sipNameNr_subtitleTextChanged 4404
#define sipName_subtitleTextChanged &sipStrings_QtMultimedia[4404]
#define sipNameNr_videoBitRateChanged 4424
#define sipName_videoBitRateChanged &sipStrings_QtMultimedia[4424]
#define sipNameNr_ChannelConfig2Dot1 4444
#define sipName_ChannelConfig2Dot1 &sipStrings_QtMultimedia[4444]
#define sipNameNr_ChannelConfig3Dot0 4463
#define sipName_ChannelConfig3Dot0 &sipStrings_QtMultimedia[4463]
#define sipNameNr_ChannelConfig3Dot1 4482
#define sipName_ChannelConfig3Dot1 &sipStrings_QtMultimedia[4482]
#define sipNameNr_ColorRange_Unknown 4501
#define sipName_ColorRange_Unknown &sipStrings_QtMultimedia[4501]
#define sipNameNr_ContributingArtist 4520
#define sipName_ContributingArtist &sipStrings_QtMultimedia[4520]
#define sipNameNr_DecibelVolumeScale 4539
#define sipName_DecibelVolumeScale &sipStrings_QtMultimedia[4539]
#define sipNameNr_Format_SamplerRect 4558
#define sipName_Format_SamplerRect &sipStrings_QtMultimedia[4558]
#define sipNameNr_FrontRightOfCenter 4577
#define sipName_FrontRightOfCenter &sipStrings_QtMultimedia[4577]
#define sipNameNr_ManualExposureTime 2809
#define sipName_ManualExposureTime &sipStrings_QtMultimedia[2809]
#define sipNameNr_PyQt6_QtMultimedia 4596
#define sipName_PyQt6_QtMultimedia &sipStrings_QtMultimedia[4596]
#define sipNameNr_QAudioBufferOutput 4615
#define sipName_QAudioBufferOutput &sipStrings_QtMultimedia[4615]
#define sipNameNr_QAudioDevice__Mode 4634
#define sipName_QAudioDevice__Mode &sipStrings_QtMultimedia[4634]
#define sipNameNr_QCamera__FlashMode 4653
#define sipName_QCamera__FlashMode &sipStrings_QtMultimedia[4653]
#define sipNameNr_QCamera__FocusMode 4672
#define sipName_QCamera__FocusMode &sipStrings_QtMultimedia[4672]
#define sipNameNr_QCamera__TorchMode 4691
#define sipName_QCamera__TorchMode &sipStrings_QtMultimedia[4691]
#define sipNameNr_QSoundEffect__Loop 4710
#define sipName_QSoundEffect__Loop &sipStrings_QtMultimedia[4710]
#define sipNameNr_WhiteBalanceCloudy 4729
#define sipName_WhiteBalanceCloudy &sipStrings_QtMultimedia[4729]
#define sipNameNr_WhiteBalanceManual 4748
#define sipName_WhiteBalanceManual &sipStrings_QtMultimedia[4748]
#define sipNameNr_WhiteBalanceSunset 4767
#define sipName_WhiteBalanceSunset &sipStrings_QtMultimedia[4767]
#define sipNameNr_audioDeviceChanged 4786
#define sipName_audioDeviceChanged &sipStrings_QtMultimedia[4786]
#define sipNameNr_audioInputsChanged 4805
#define sipName_audioInputsChanged &sipStrings_QtMultimedia[4805]
#define sipNameNr_audioOutputChanged 4824
#define sipName_audioOutputChanged &sipStrings_QtMultimedia[4824]
#define sipNameNr_defaultAudioOutput 4843
#define sipName_defaultAudioOutput &sipStrings_QtMultimedia[4843]
#define sipNameNr_manualExposureTime 4862
#define sipName_manualExposureTime &sipStrings_QtMultimedia[4862]
#define sipNameNr_mediaFormatChanged 4881
#define sipName_mediaFormatChanged &sipStrings_QtMultimedia[4881]
#define sipNameNr_mediaStatusChanged 4900
#define sipName_mediaStatusChanged &sipStrings_QtMultimedia[4900]
#define sipNameNr_resolveForEncoding 4919
#define sipName_resolveForEncoding &sipStrings_QtMultimedia[4919]
#define sipNameNr_setAudioSampleRate 4938
#define sipName_setAudioSampleRate &sipStrings_QtMultimedia[4938]
#define sipNameNr_setPlaybackOptions 3336
#define sipName_setPlaybackOptions &sipStrings_QtMultimedia[3336]
#define sipNameNr_setStreamFrameRate 4957
#define sipName_setStreamFrameRate &sipStrings_QtMultimedia[4957]
#define sipNameNr_setVideoFrameInput 4976
#define sipName_setVideoFrameInput &sipStrings_QtMultimedia[4976]
#define sipNameNr_setVideoResolution 4995
#define sipName_setVideoResolution &sipStrings_QtMultimedia[4995]
#define sipNameNr_setYCbCrColorSpace 5014
#define sipName_setYCbCrColorSpace &sipStrings_QtMultimedia[5014]
#define sipNameNr_supportedMimeTypes 5033
#define sipName_supportedMimeTypes &sipStrings_QtMultimedia[5033]
#define sipNameNr_videoInputsChanged 5052
#define sipName_videoInputsChanged &sipStrings_QtMultimedia[5052]
#define sipNameNr_videoOutputChanged 5071
#define sipName_videoOutputChanged &sipStrings_QtMultimedia[5071]
#define sipNameNr_AccessDeniedError 5090
#define sipName_AccessDeniedError &sipStrings_QtMultimedia[5090]
#define sipNameNr_BottomFrontCenter 5108
#define sipName_BottomFrontCenter &sipStrings_QtMultimedia[5108]
#define sipNameNr_ChannelConfigMono 5126
#define sipName_ChannelConfigMono &sipStrings_QtMultimedia[5126]
#define sipNameNr_ColorSpace_BT2020 5144
#define sipName_ColorSpace_BT2020 &sipStrings_QtMultimedia[5144]
#define sipNameNr_DontDrawSubtitles 5162
#define sipName_DontDrawSubtitles &sipStrings_QtMultimedia[5162]
#define sipNameNr_ExposureFireworks 5180
#define sipName_ExposureFireworks &sipStrings_QtMultimedia[5180]
#define sipNameNr_ExposureLandscape 5198
#define sipName_ExposureLandscape &sipStrings_QtMultimedia[5198]
#define sipNameNr_FocusModeAutoNear 5216
#define sipName_FocusModeAutoNear &sipStrings_QtMultimedia[5216]
#define sipNameNr_FocusModeInfinity 5234
#define sipName_FocusModeInfinity &sipStrings_QtMultimedia[5234]
#define sipNameNr_FrontLeftOfCenter 5252
#define sipName_FrontLeftOfCenter &sipStrings_QtMultimedia[5252]
#define sipNameNr_LinearVolumeScale 5270
#define sipName_LinearVolumeScale &sipStrings_QtMultimedia[5270]
#define sipNameNr_NotSupportedError 5288
#define sipName_NotSupportedError &sipStrings_QtMultimedia[5288]
#define sipNameNr_QAudioBufferInput 5306
#define sipName_QAudioBufferInput &sipStrings_QtMultimedia[5306]
#define sipNameNr_QCapturableWindow 5324
#define sipName_QCapturableWindow &sipStrings_QtMultimedia[5324]
#define sipNameNr_QVideoFrameFormat 5342
#define sipName_QVideoFrameFormat &sipStrings_QtMultimedia[5342]
#define sipNameNr_QtVideo__Rotation 5360
#define sipName_QtVideo__Rotation &sipStrings_QtMultimedia[5360]
#define sipNameNr_UnspecifiedFormat 5378
#define sipName_UnspecifiedFormat &sipStrings_QtMultimedia[5378]
#define sipNameNr_WhiteBalanceFlash 5396
#define sipName_WhiteBalanceFlash &sipStrings_QtMultimedia[5396]
#define sipNameNr_WhiteBalanceShade 5414
#define sipName_WhiteBalanceShade &sipStrings_QtMultimedia[5414]
#define sipNameNr_audioBufferOutput 5432
#define sipName_audioBufferOutput &sipStrings_QtMultimedia[5432]
#define sipNameNr_audioChannelCount 5450
#define sipName_audioChannelCount &sipStrings_QtMultimedia[5450]
#define sipNameNr_audioInputChanged 5468
#define sipName_audioInputChanged &sipStrings_QtMultimedia[5468]
#define sipNameNr_bufferedTimeRange 5486
#define sipName_bufferedTimeRange &sipStrings_QtMultimedia[5486]
#define sipNameNr_capturableWindows 5504
#define sipName_capturableWindows &sipStrings_QtMultimedia[5504]
#define sipNameNr_defaultAudioInput 5522
#define sipName_defaultAudioInput &sipStrings_QtMultimedia[5522]
#define sipNameNr_defaultVideoInput 5540
#define sipName_defaultVideoInput &sipStrings_QtMultimedia[5540]
#define sipNameNr_durationForFrames 5558
#define sipName_durationForFrames &sipStrings_QtMultimedia[5558]
#define sipNameNr_fileFormatChanged 5576
#define sipName_fileFormatChanged &sipStrings_QtMultimedia[5576]
#define sipNameNr_focusPointChanged 5594
#define sipName_focusPointChanged &sipStrings_QtMultimedia[5594]
#define sipNameNr_framesForDuration 5612
#define sipName_framesForDuration &sipStrings_QtMultimedia[5612]
#define sipNameNr_isDecodingChanged 5630
#define sipName_isDecodingChanged &sipStrings_QtMultimedia[5630]
#define sipNameNr_isFormatSupported 5648
#define sipName_isFormatSupported &sipStrings_QtMultimedia[5648]
#define sipNameNr_isReadyForCapture 5666
#define sipName_isReadyForCapture &sipStrings_QtMultimedia[5666]
#define sipNameNr_maximumSampleRate 5684
#define sipName_maximumSampleRate &sipStrings_QtMultimedia[5684]
#define sipNameNr_maximumZoomFactor 5702
#define sipName_maximumZoomFactor &sipStrings_QtMultimedia[5702]
#define sipNameNr_minimumSampleRate 5720
#define sipName_minimumSampleRate &sipStrings_QtMultimedia[5720]
#define sipNameNr_minimumZoomFactor 5738
#define sipName_minimumZoomFactor &sipStrings_QtMultimedia[5738]
#define sipNameNr_pitchCompensation 5756
#define sipName_pitchCompensation &sipStrings_QtMultimedia[5756]
#define sipNameNr_resolutionChanged 5774
#define sipName_resolutionChanged &sipStrings_QtMultimedia[5774]
#define sipNameNr_scanLineDirection 5792
#define sipName_scanLineDirection &sipStrings_QtMultimedia[5792]
#define sipNameNr_setNetworkTimeout 4206
#define sipName_setNetworkTimeout &sipStrings_QtMultimedia[4206]
#define sipNameNr_setOutputLocation 5810
#define sipName_setOutputLocation &sipStrings_QtMultimedia[5810]
#define sipNameNr_setPlaybackIntent 4226
#define sipName_setPlaybackIntent &sipStrings_QtMultimedia[4226]
#define sipNameNr_setVideoFrameRate 5828
#define sipName_setVideoFrameRate &sipStrings_QtMultimedia[5828]
#define sipNameNr_supportedFeatures 5846
#define sipName_supportedFeatures &sipStrings_QtMultimedia[5846]
#define sipNameNr_videoFrameChanged 5864
#define sipName_videoFrameChanged &sipStrings_QtMultimedia[5864]
#define sipNameNr_zoomFactorChanged 5882
#define sipName_zoomFactorChanged &sipStrings_QtMultimedia[5882]
#define sipNameNr_BottomFrontRight 5900
#define sipName_BottomFrontRight &sipStrings_QtMultimedia[5900]
#define sipNameNr_ColorRange_Video 5917
#define sipName_ColorRange_Video &sipStrings_QtMultimedia[5917]
#define sipNameNr_ColorSpace_BT601 5934
#define sipName_ColorSpace_BT601 &sipStrings_QtMultimedia[5934]
#define sipNameNr_ColorSpace_BT709 5951
#define sipName_ColorSpace_BT709 &sipStrings_QtMultimedia[5951]
#define sipNameNr_ColorTemperature 4347
#define sipName_ColorTemperature &sipStrings_QtMultimedia[4347]
#define sipNameNr_CubicVolumeScale 5968
#define sipName_CubicVolumeScale &sipStrings_QtMultimedia[5968]
#define sipNameNr_CustomFocusPoint 4367
#define sipName_CustomFocusPoint &sipStrings_QtMultimedia[4367]
#define sipNameNr_ExposurePortrait 5985
#define sipName_ExposurePortrait &sipStrings_QtMultimedia[5985]
#define sipNameNr_FocusModeAutoFar 6002
#define sipName_FocusModeAutoFar &sipStrings_QtMultimedia[6002]
#define sipNameNr_Format_YUV420P10 6019
#define sipName_Format_YUV420P10 &sipStrings_QtMultimedia[6019]
#define sipNameNr_QCamera__Feature 6036
#define sipName_QCamera__Feature &sipStrings_QtMultimedia[6036]
#define sipNameNr_QPlaybackOptions 6053
#define sipName_QPlaybackOptions &sipStrings_QtMultimedia[6053]
#define sipNameNr_QVideoFrameInput 6070
#define sipName_QVideoFrameInput &sipStrings_QtMultimedia[6070]
#define sipNameNr_RhiTextureHandle 6087
#define sipName_RhiTextureHandle &sipStrings_QtMultimedia[6087]
#define sipNameNr_WhiteBalanceAuto 6104
#define sipName_WhiteBalanceAuto &sipStrings_QtMultimedia[6104]
#define sipNameNr_WhiteBalanceMode 1263
#define sipName_WhiteBalanceMode &sipStrings_QtMultimedia[1263]
#define sipNameNr_activeAudioTrack 6121
#define sipName_activeAudioTrack &sipStrings_QtMultimedia[6121]
#define sipNameNr_activeVideoTrack 6138
#define sipName_activeVideoTrack &sipStrings_QtMultimedia[6138]
#define sipNameNr_audioBufferInput 6155
#define sipName_audioBufferInput &sipStrings_QtMultimedia[6155]
#define sipNameNr_bufferFrameCount 6172
#define sipName_bufferFrameCount &sipStrings_QtMultimedia[6172]
#define sipNameNr_bytesForDuration 6189
#define sipName_bytesForDuration &sipStrings_QtMultimedia[6189]
#define sipNameNr_colorTemperature 6206
#define sipName_colorTemperature &sipStrings_QtMultimedia[6206]
#define sipNameNr_customFocusPoint 6223
#define sipName_customFocusPoint &sipStrings_QtMultimedia[6223]
#define sipNameNr_disconnectNotify 6240
#define sipName_disconnectNotify &sipStrings_QtMultimedia[6240]
#define sipNameNr_durationForBytes 6257
#define sipName_durationForBytes &sipStrings_QtMultimedia[6257]
#define sipNameNr_flashModeChanged 6274
#define sipName_flashModeChanged &sipStrings_QtMultimedia[6274]
#define sipNameNr_focusModeChanged 6291
#define sipName_focusModeChanged &sipStrings_QtMultimedia[6291]
#define sipNameNr_loopCountChanged 6308
#define sipName_loopCountChanged &sipStrings_QtMultimedia[6308]
#define sipNameNr_photoResolutions 6325
#define sipName_photoResolutions &sipStrings_QtMultimedia[6325]
#define sipNameNr_setChannelConfig 6342
#define sipName_setChannelConfig &sipStrings_QtMultimedia[6342]
#define sipNameNr_setColorTransfer 6359
#define sipName_setColorTransfer &sipStrings_QtMultimedia[6359]
#define sipNameNr_setFocusDistance 6376
#define sipName_setFocusDistance &sipStrings_QtMultimedia[6376]
#define sipNameNr_setRotationAngle 6393
#define sipName_setRotationAngle &sipStrings_QtMultimedia[6393]
#define sipNameNr_setScreenCapture 6410
#define sipName_setScreenCapture &sipStrings_QtMultimedia[6410]
#define sipNameNr_setWindowCapture 6427
#define sipName_setWindowCapture &sipStrings_QtMultimedia[6427]
#define sipNameNr_supportedFormats 6444
#define sipName_supportedFormats &sipStrings_QtMultimedia[6444]
#define sipNameNr_torchModeChanged 6461
#define sipName_torchModeChanged &sipStrings_QtMultimedia[6461]
#define sipNameNr_videoSizeChanged 6478
#define sipName_videoSizeChanged &sipStrings_QtMultimedia[6478]
#define sipNameNr_whiteBalanceMode 6495
#define sipName_whiteBalanceMode &sipStrings_QtMultimedia[6495]
#define sipNameNr_BottomFrontLeft 6512
#define sipName_BottomFrontLeft &sipStrings_QtMultimedia[6512]
#define sipNameNr_ColorRange_Full 6528
#define sipName_ColorRange_Full &sipStrings_QtMultimedia[6528]
#define sipNameNr_ExposureBarcode 6544
#define sipName_ExposureBarcode &sipStrings_QtMultimedia[6544]
#define sipNameNr_ExposureTheatre 6560
#define sipName_ExposureTheatre &sipStrings_QtMultimedia[6560]
#define sipNameNr_FocusModeManual 6576
#define sipName_FocusModeManual &sipStrings_QtMultimedia[6576]
#define sipNameNr_Format_ABGR8888 6592
#define sipName_Format_ABGR8888 &sipStrings_QtMultimedia[6592]
#define sipNameNr_Format_ARGB8888 6608
#define sipName_Format_ARGB8888 &sipStrings_QtMultimedia[6608]
#define sipNameNr_Format_BGRA8888 6624
#define sipName_Format_BGRA8888 &sipStrings_QtMultimedia[6624]
#define sipNameNr_Format_BGRX8888 6640
#define sipName_Format_BGRX8888 &sipStrings_QtMultimedia[6640]
#define sipNameNr_Format_RGBA8888 6656
#define sipName_Format_RGBA8888 &sipStrings_QtMultimedia[6656]
#define sipNameNr_Format_RGBX8888 6672
#define sipName_Format_RGBX8888 &sipStrings_QtMultimedia[6672]
#define sipNameNr_Format_XBGR8888 6688
#define sipName_Format_XBGR8888 &sipStrings_QtMultimedia[6688]
#define sipNameNr_Format_XRGB8888 6704
#define sipName_Format_XRGB8888 &sipStrings_QtMultimedia[6704]
#define sipNameNr_OutOfSpaceError 6720
#define sipName_OutOfSpaceError &sipStrings_QtMultimedia[6720]
#define sipNameNr_QMediaTimeRange 6736
#define sipName_QMediaTimeRange &sipStrings_QtMultimedia[6736]
#define sipNameNr_TwoPassEncoding 6752
#define sipName_TwoPassEncoding &sipStrings_QtMultimedia[6752]
#define sipNameNr_UnknownPosition 6768
#define sipName_UnknownPosition &sipStrings_QtMultimedia[6768]
#define sipNameNr_VeryHighQuality 6784
#define sipName_VeryHighQuality &sipStrings_QtMultimedia[6784]
#define sipNameNr_YCbCrColorSpace 216
#define sipName_YCbCrColorSpace &sipStrings_QtMultimedia[216]
#define sipNameNr_YCbCr_Undefined 6800
#define sipName_YCbCr_Undefined &sipStrings_QtMultimedia[6800]
#define sipNameNr_aspectRatioMode 6816
#define sipName_aspectRatioMode &sipStrings_QtMultimedia[6816]
#define sipNameNr_audioSampleRate 6832
#define sipName_audioSampleRate &sipStrings_QtMultimedia[6832]
#define sipNameNr_autoStopChanged 6848
#define sipName_autoStopChanged &sipStrings_QtMultimedia[6848]
#define sipNameNr_backgroundColor 6864
#define sipName_backgroundColor &sipStrings_QtMultimedia[6864]
#define sipNameNr_bufferAvailable 6880
#define sipName_bufferAvailable &sipStrings_QtMultimedia[6880]
#define sipNameNr_correctionAngle 6896
#define sipName_correctionAngle &sipStrings_QtMultimedia[6896]
#define sipNameNr_durationChanged 6912
#define sipName_durationChanged &sipStrings_QtMultimedia[6912]
#define sipNameNr_framesAvailable 6928
#define sipName_framesAvailable &sipStrings_QtMultimedia[6928]
#define sipNameNr_hasAudioChanged 6944
#define sipName_hasAudioChanged &sipStrings_QtMultimedia[6944]
#define sipNameNr_hasVideoChanged 6960
#define sipName_hasVideoChanged &sipStrings_QtMultimedia[6960]
#define sipNameNr_metaDataChanged 6976
#define sipName_metaDataChanged &sipStrings_QtMultimedia[6976]
#define sipNameNr_playbackOptions 6992
#define sipName_playbackOptions &sipStrings_QtMultimedia[6992]
#define sipNameNr_positionChanged 7008
#define sipName_positionChanged &sipStrings_QtMultimedia[7008]
#define sipNameNr_preferredFormat 7024
#define sipName_preferredFormat &sipStrings_QtMultimedia[7024]
#define sipNameNr_recorderChanged 7040
#define sipName_recorderChanged &sipStrings_QtMultimedia[7040]
#define sipNameNr_removeTimeRange 7056
#define sipName_removeTimeRange &sipStrings_QtMultimedia[7056]
#define sipNameNr_seekableChanged 7072
#define sipName_seekableChanged &sipStrings_QtMultimedia[7072]
#define sipNameNr_sendAudioBuffer 7088
#define sipName_sendAudioBuffer &sipStrings_QtMultimedia[7088]
#define sipNameNr_setAudioBitRate 7104
#define sipName_setAudioBitRate &sipStrings_QtMultimedia[7104]
#define sipNameNr_setCameraDevice 7120
#define sipName_setCameraDevice &sipStrings_QtMultimedia[7120]
#define sipNameNr_setCameraFormat 7136
#define sipName_setCameraFormat &sipStrings_QtMultimedia[7136]
#define sipNameNr_setChannelCount 7152
#define sipName_setChannelCount &sipStrings_QtMultimedia[7152]
#define sipNameNr_setEncodingMode 7168
#define sipName_setEncodingMode &sipStrings_QtMultimedia[7168]
#define sipNameNr_setExposureMode 7184
#define sipName_setExposureMode &sipStrings_QtMultimedia[7184]
#define sipNameNr_setImageCapture 7200
#define sipName_setImageCapture &sipStrings_QtMultimedia[7200]
#define sipNameNr_setOutputDevice 7216
#define sipName_setOutputDevice &sipStrings_QtMultimedia[7216]
#define sipNameNr_setPlaybackRate 7232
#define sipName_setPlaybackRate &sipStrings_QtMultimedia[7232]
#define sipNameNr_setSampleFormat 7248
#define sipName_setSampleFormat &sipStrings_QtMultimedia[7248]
#define sipNameNr_setSourceDevice 7264
#define sipName_setSourceDevice &sipStrings_QtMultimedia[7264]
#define sipNameNr_setSubtitleText 7280
#define sipName_setSubtitleText &sipStrings_QtMultimedia[7280]
#define sipNameNr_setVideoBitRate 7296
#define sipName_setVideoBitRate &sipStrings_QtMultimedia[7296]
#define sipNameNr_streamFrameRate 7312
#define sipName_streamFrameRate &sipStrings_QtMultimedia[7312]
#define sipNameNr_videoFrameInput 7328
#define sipName_videoFrameInput &sipStrings_QtMultimedia[7328]
#define sipNameNr_videoResolution 7344
#define sipName_videoResolution &sipStrings_QtMultimedia[7344]
#define sipNameNr_yCbCrColorSpace 7360
#define sipName_yCbCrColorSpace &sipStrings_QtMultimedia[7360]
#define sipNameNr_BufferingMedia 7376
#define sipName_BufferingMedia &sipStrings_QtMultimedia[7376]
#define sipNameNr_ConversionMode 719
#define sipName_ConversionMode &sipStrings_QtMultimedia[719]
#define sipNameNr_ExposureAction 7391
#define sipName_ExposureAction &sipStrings_QtMultimedia[7391]
#define sipNameNr_ExposureManual 7406
#define sipName_ExposureManual &sipStrings_QtMultimedia[7406]
#define sipNameNr_ExposureSports 7421
#define sipName_ExposureSports &sipStrings_QtMultimedia[7421]
#define sipNameNr_ExposureSunset 7436
#define sipName_ExposureSunset &sipStrings_QtMultimedia[7436]
#define sipNameNr_Format_Invalid 7451
#define sipName_Format_Invalid &sipStrings_QtMultimedia[7451]
#define sipNameNr_Format_YUV420P 7466
#define sipName_Format_YUV420P &sipStrings_QtMultimedia[7466]
#define sipNameNr_Format_YUV422P 7481
#define sipName_Format_YUV422P &sipStrings_QtMultimedia[7481]
#define sipNameNr_IsoSensitivity 2007
#define sipName_IsoSensitivity &sipStrings_QtMultimedia[2007]
#define sipNameNr_PlaybackIntent 350
#define sipName_PlaybackIntent &sipStrings_QtMultimedia[350]
#define sipNameNr_QCamera__Error 7496
#define sipName_QCamera__Error &sipStrings_QtMultimedia[7496]
#define sipNameNr_QMediaMetaData 7511
#define sipName_QMediaMetaData &sipStrings_QtMultimedia[7511]
#define sipNameNr_QMediaRecorder 7526
#define sipName_QMediaRecorder &sipStrings_QtMultimedia[7526]
#define sipNameNr_QScreenCapture 7541
#define sipName_QScreenCapture &sipStrings_QtMultimedia[7541]
#define sipNameNr_QWindowCapture 7556
#define sipName_QWindowCapture &sipStrings_QtMultimedia[7556]
#define sipNameNr_RecordingState 7571
#define sipName_RecordingState &sipStrings_QtMultimedia[7571]
#define sipNameNr_SuspendedState 7586
#define sipName_SuspendedState &sipStrings_QtMultimedia[7586]
#define sipNameNr_ThumbnailImage 7601
#define sipName_ThumbnailImage &sipStrings_QtMultimedia[7601]
#define sipNameNr_TopFrontCenter 7616
#define sipName_TopFrontCenter &sipStrings_QtMultimedia[7616]
#define sipNameNr_VeryLowQuality 7631
#define sipName_VeryLowQuality &sipStrings_QtMultimedia[7631]
#define sipNameNr_VideoFrameRate 5831
#define sipName_VideoFrameRate &sipStrings_QtMultimedia[5831]
#define sipNameNr_YCbCr_xvYCC601 7646
#define sipName_YCbCr_xvYCC601 &sipStrings_QtMultimedia[7646]
#define sipNameNr_YCbCr_xvYCC709 7661
#define sipName_YCbCr_xvYCC709 &sipStrings_QtMultimedia[7661]
#define sipNameNr_actualLocation 7676
#define sipName_actualLocation &sipStrings_QtMultimedia[7676]
#define sipNameNr_audioCodecName 7691
#define sipName_audioCodecName &sipStrings_QtMultimedia[7691]
#define sipNameNr_bufferProgress 7706
#define sipName_bufferProgress &sipStrings_QtMultimedia[7706]
#define sipNameNr_bytesAvailable 7721
#define sipName_bytesAvailable &sipStrings_QtMultimedia[7721]
#define sipNameNr_bytesForFrames 7736
#define sipName_bytesForFrames &sipStrings_QtMultimedia[7736]
#define sipNameNr_bytesPerSample 7751
#define sipName_bytesPerSample &sipStrings_QtMultimedia[7751]
#define sipNameNr_captureSession 7766
#define sipName_captureSession &sipStrings_QtMultimedia[7766]
#define sipNameNr_fileFormatName 7781
#define sipName_fileFormatName &sipStrings_QtMultimedia[7781]
#define sipNameNr_framesForBytes 7796
#define sipName_framesForBytes &sipStrings_QtMultimedia[7796]
#define sipNameNr_imageAvailable 7811
#define sipName_imageAvailable &sipStrings_QtMultimedia[7811]
#define sipNameNr_isoSensitivity 7826
#define sipName_isoSensitivity &sipStrings_QtMultimedia[7826]
#define sipNameNr_loopsRemaining 7841
#define sipName_loopsRemaining &sipStrings_QtMultimedia[7841]
#define sipNameNr_networkTimeout 7856
#define sipName_networkTimeout &sipStrings_QtMultimedia[7856]
#define sipNameNr_outputLocation 7871
#define sipName_outputLocation &sipStrings_QtMultimedia[7871]
#define sipNameNr_playbackIntent 7886
#define sipName_playbackIntent &sipStrings_QtMultimedia[7886]
#define sipNameNr_playingChanged 7901
#define sipName_playingChanged &sipStrings_QtMultimedia[7901]
#define sipNameNr_processedUSecs 7916
#define sipName_processedUSecs &sipStrings_QtMultimedia[7916]
#define sipNameNr_qualityChanged 7931
#define sipName_qualityChanged &sipStrings_QtMultimedia[7931]
#define sipNameNr_removeInterval 7946
#define sipName_removeInterval &sipStrings_QtMultimedia[7946]
#define sipNameNr_resetProbeSize 7961
#define sipName_resetProbeSize &sipStrings_QtMultimedia[7961]
#define sipNameNr_sendVideoFrame 7976
#define sipName_sendVideoFrame &sipStrings_QtMultimedia[7976]
#define sipNameNr_setAudioDevice 7991
#define sipName_setAudioDevice &sipStrings_QtMultimedia[7991]
#define sipNameNr_setAudioFormat 8006
#define sipName_setAudioFormat &sipStrings_QtMultimedia[8006]
#define sipNameNr_setAudioOutput 8021
#define sipName_setAudioOutput &sipStrings_QtMultimedia[8021]
#define sipNameNr_setMediaFormat 8036
#define sipName_setMediaFormat &sipStrings_QtMultimedia[8036]
#define sipNameNr_setVideoOutput 8051
#define sipName_setVideoOutput &sipStrings_QtMultimedia[8051]
#define sipNameNr_subtitleTracks 8066
#define sipName_subtitleTracks &sipStrings_QtMultimedia[8066]
#define sipNameNr_videoCodecName 8081
#define sipName_videoCodecName &sipStrings_QtMultimedia[8081]
#define sipNameNr_videoFrameRate 8096
#define sipName_videoFrameRate &sipStrings_QtMultimedia[8096]
#define sipNameNr_BufferedMedia 8111
#define sipName_BufferedMedia &sipStrings_QtMultimedia[8111]
#define sipNameNr_CaptureFailed 8125
#define sipName_CaptureFailed &sipStrings_QtMultimedia[8125]
#define sipNameNr_ChannelConfig 806
#define sipName_ChannelConfig &sipStrings_QtMultimedia[806]
#define sipNameNr_ColorTransfer 384
#define sipName_ColorTransfer &sipStrings_QtMultimedia[384]
#define sipNameNr_CoverArtImage 8139
#define sipName_CoverArtImage &sipStrings_QtMultimedia[8139]
#define sipNameNr_ExposureBeach 8153
#define sipName_ExposureBeach &sipStrings_QtMultimedia[8153]
#define sipNameNr_ExposureNight 8167
#define sipName_ExposureNight &sipStrings_QtMultimedia[8167]
#define sipNameNr_ExposureParty 8181
#define sipName_ExposureParty &sipStrings_QtMultimedia[8181]
#define sipNameNr_FocusDistance 6379
#define sipName_FocusDistance &sipStrings_QtMultimedia[6379]
#define sipNameNr_FocusModeAuto 8195
#define sipName_FocusModeAuto &sipStrings_QtMultimedia[8195]
#define sipNameNr_HasHdrContent 8209
#define sipName_HasHdrContent &sipStrings_QtMultimedia[8209]
#define sipNameNr_InternalError 8223
#define sipName_InternalError &sipStrings_QtMultimedia[8223]
#define sipNameNr_LeadPerformer 8237
#define sipName_LeadPerformer &sipStrings_QtMultimedia[8237]
#define sipNameNr_NormalQuality 8251
#define sipName_NormalQuality &sipStrings_QtMultimedia[8251]
#define sipNameNr_NotReadyError 8265
#define sipName_NotReadyError &sipStrings_QtMultimedia[8265]
#define sipNameNr_PlaybackState 834
#define sipName_PlaybackState &sipStrings_QtMultimedia[834]
#define sipNameNr_QAudio__Error 8279
#define sipName_QAudio__Error &sipStrings_QtMultimedia[8279]
#define sipNameNr_QAudio__State 8293
#define sipName_QAudio__State &sipStrings_QtMultimedia[8293]
#define sipNameNr_QAudioDecoder 8307
#define sipName_QAudioDecoder &sipStrings_QtMultimedia[8307]
#define sipNameNr_QCameraDevice 8321
#define sipName_QCameraDevice &sipStrings_QtMultimedia[8321]
#define sipNameNr_QCameraFormat 8335
#define sipName_QCameraFormat &sipStrings_QtMultimedia[8335]
#define sipNameNr_QImageCapture 8349
#define sipName_QImageCapture &sipStrings_QtMultimedia[8349]
#define sipNameNr_QMediaDevices 8363
#define sipName_QMediaDevices &sipStrings_QtMultimedia[8363]
#define sipNameNr_RecorderState 601
#define sipName_RecorderState &sipStrings_QtMultimedia[601]
#define sipNameNr_RequiresVideo 8377
#define sipName_RequiresVideo &sipStrings_QtMultimedia[8377]
#define sipNameNr_ResourceError 8391
#define sipName_ResourceError &sipStrings_QtMultimedia[8391]
#define sipNameNr_RotationAngle 1134
#define sipName_RotationAngle &sipStrings_QtMultimedia[1134]
#define sipNameNr_TopBackCenter 8405
#define sipName_TopBackCenter &sipStrings_QtMultimedia[8405]
#define sipNameNr_TopFrontRight 8419
#define sipName_TopFrontRight &sipStrings_QtMultimedia[8419]
#define sipNameNr_UnderrunError 8433
#define sipName_UnderrunError &sipStrings_QtMultimedia[8433]
#define sipNameNr_activeChanged 8447
#define sipName_activeChanged &sipStrings_QtMultimedia[8447]
#define sipNameNr_bytesPerFrame 8461
#define sipName_bytesPerFrame &sipStrings_QtMultimedia[8461]
#define sipNameNr_cameraChanged 8475
#define sipName_cameraChanged &sipStrings_QtMultimedia[8475]
#define sipNameNr_captureToFile 8489
#define sipName_captureToFile &sipStrings_QtMultimedia[8489]
#define sipNameNr_channelConfig 8503
#define sipName_channelConfig &sipStrings_QtMultimedia[8503]
#define sipNameNr_channelOffset 8517
#define sipName_channelOffset &sipStrings_QtMultimedia[8517]
#define sipNameNr_colorTransfer 8531
#define sipName_colorTransfer &sipStrings_QtMultimedia[8531]
#define sipNameNr_connectNotify 6243
#define sipName_connectNotify &sipStrings_QtMultimedia[6243]
#define sipNameNr_convertVolume 8545
#define sipName_convertVolume &sipStrings_QtMultimedia[8545]
#define sipNameNr_deviceChanged 8559
#define sipName_deviceChanged &sipStrings_QtMultimedia[8559]
#define sipNameNr_errorOccurred 8573
#define sipName_errorOccurred &sipStrings_QtMultimedia[8573]
#define sipNameNr_focusDistance 8587
#define sipName_focusDistance &sipStrings_QtMultimedia[8587]
#define sipNameNr_formatChanged 8601
#define sipName_formatChanged &sipStrings_QtMultimedia[8601]
#define sipNameNr_imageCaptured 8615
#define sipName_imageCaptured &sipStrings_QtMultimedia[8615]
#define sipNameNr_loadedChanged 8629
#define sipName_loadedChanged &sipStrings_QtMultimedia[8629]
#define sipNameNr_playbackState 8643
#define sipName_playbackState &sipStrings_QtMultimedia[8643]
#define sipNameNr_recorderState 8657
#define sipName_recorderState &sipStrings_QtMultimedia[8657]
#define sipNameNr_rotationAngle 8671
#define sipName_rotationAngle &sipStrings_QtMultimedia[8671]
#define sipNameNr_screenCapture 8685
#define sipName_screenCapture &sipStrings_QtMultimedia[8685]
#define sipNameNr_screenChanged 8699
#define sipName_screenChanged &sipStrings_QtMultimedia[8699]
#define sipNameNr_setAudioCodec 8713
#define sipName_setAudioCodec &sipStrings_QtMultimedia[8713]
#define sipNameNr_setAudioInput 8727
#define sipName_setAudioInput &sipStrings_QtMultimedia[8727]
#define sipNameNr_setBufferSize 8741
#define sipName_setBufferSize &sipStrings_QtMultimedia[8741]
#define sipNameNr_setColorRange 8755
#define sipName_setColorRange &sipStrings_QtMultimedia[8755]
#define sipNameNr_setColorSpace 8769
#define sipName_setColorSpace &sipStrings_QtMultimedia[8769]
#define sipNameNr_setFileFormat 8783
#define sipName_setFileFormat &sipStrings_QtMultimedia[8783]
#define sipNameNr_setResolution 8797
#define sipName_setResolution &sipStrings_QtMultimedia[8797]
#define sipNameNr_setSampleRate 8811
#define sipName_setSampleRate &sipStrings_QtMultimedia[8811]
#define sipNameNr_setVideoCodec 8825
#define sipName_setVideoCodec &sipStrings_QtMultimedia[8825]
#define sipNameNr_setVideoFrame 8839
#define sipName_setVideoFrame &sipStrings_QtMultimedia[8839]
#define sipNameNr_setZoomFactor 8853
#define sipName_setZoomFactor &sipStrings_QtMultimedia[8853]
#define sipNameNr_sourceChanged 8867
#define sipName_sourceChanged &sipStrings_QtMultimedia[8867]
#define sipNameNr_statusChanged 8881
#define sipName_statusChanged &sipStrings_QtMultimedia[8881]
#define sipNameNr_surfaceFormat 8895
#define sipName_surfaceFormat &sipStrings_QtMultimedia[8895]
#define sipNameNr_tracksChanged 8909
#define sipName_tracksChanged &sipStrings_QtMultimedia[8909]
#define sipNameNr_volumeChanged 8923
#define sipName_volumeChanged &sipStrings_QtMultimedia[8923]
#define sipNameNr_windowCapture 8937
#define sipName_windowCapture &sipStrings_QtMultimedia[8937]
#define sipNameNr_windowChanged 8951
#define sipName_windowChanged &sipStrings_QtMultimedia[8951]
#define sipNameNr_AudioBitRate 7107
#define sipName_AudioBitRate &sipStrings_QtMultimedia[7107]
#define sipNameNr_Clockwise180 8965
#define sipName_Clockwise180 &sipStrings_QtMultimedia[8965]
#define sipNameNr_Clockwise270 8978
#define sipName_Clockwise270 &sipStrings_QtMultimedia[8978]
#define sipNameNr_EncodingMode 750
#define sipName_EncodingMode &sipStrings_QtMultimedia[750]
#define sipNameNr_ExposureAuto 8991
#define sipName_ExposureAuto &sipStrings_QtMultimedia[8991]
#define sipNameNr_ExposureMode 2463
#define sipName_ExposureMode &sipStrings_QtMultimedia[2463]
#define sipNameNr_ExposureSnow 9004
#define sipName_ExposureSnow &sipStrings_QtMultimedia[9004]
#define sipNameNr_InvalidMedia 9017
#define sipName_InvalidMedia &sipStrings_QtMultimedia[9017]
#define sipNameNr_LoadingMedia 9030
#define sipName_LoadingMedia &sipStrings_QtMultimedia[9030]
#define sipNameNr_NetworkError 9043
#define sipName_NetworkError &sipStrings_QtMultimedia[9043]
#define sipNameNr_PaintOptions 1371
#define sipName_PaintOptions &sipStrings_QtMultimedia[1371]
#define sipNameNr_PlayingState 9056
#define sipName_PlayingState &sipStrings_QtMultimedia[9056]
#define sipNameNr_QAudioBuffer 9069
#define sipName_QAudioBuffer &sipStrings_QtMultimedia[9069]
#define sipNameNr_QAudioDevice 9082
#define sipName_QAudioDevice &sipStrings_QtMultimedia[9082]
#define sipNameNr_QAudioFormat 9095
#define sipName_QAudioFormat &sipStrings_QtMultimedia[9095]
#define sipNameNr_QAudioOutput 9108
#define sipName_QAudioOutput &sipStrings_QtMultimedia[9108]
#define sipNameNr_QAudioSource 9121
#define sipName_QAudioSource &sipStrings_QtMultimedia[9121]
#define sipNameNr_QMediaFormat 9134
#define sipName_QMediaFormat &sipStrings_QtMultimedia[9134]
#define sipNameNr_QMediaPlayer 9147
#define sipName_QMediaPlayer &sipStrings_QtMultimedia[9147]
#define sipNameNr_QSoundEffect 9160
#define sipName_QSoundEffect &sipStrings_QtMultimedia[9160]
#define sipNameNr_ResolveFlags 1108
#define sipName_ResolveFlags &sipStrings_QtMultimedia[1108]
#define sipNameNr_SampleFormat 1054
#define sipName_SampleFormat &sipStrings_QtMultimedia[1054]
#define sipNameNr_StalledMedia 9173
#define sipName_StalledMedia &sipStrings_QtMultimedia[9173]
#define sipNameNr_StoppedState 9186
#define sipName_StoppedState &sipStrings_QtMultimedia[9186]
#define sipNameNr_TopBackRight 9199
#define sipName_TopBackRight &sipStrings_QtMultimedia[9199]
#define sipNameNr_TopFrontLeft 9212
#define sipName_TopFrontLeft &sipStrings_QtMultimedia[9212]
#define sipNameNr_TopSideRight 9225
#define sipName_TopSideRight &sipStrings_QtMultimedia[9225]
#define sipNameNr_VideoBitRate 7299
#define sipName_VideoBitRate &sipStrings_QtMultimedia[7299]
#define sipNameNr_YCbCr_BT2020 9238
#define sipName_YCbCr_BT2020 &sipStrings_QtMultimedia[9238]
#define sipNameNr_addTimeRange 9251
#define sipName_addTimeRange &sipStrings_QtMultimedia[9251]
#define sipNameNr_audioBitRate 9264
#define sipName_audioBitRate &sipStrings_QtMultimedia[9264]
#define sipNameNr_audioOutputs 9277
#define sipName_audioOutputs &sipStrings_QtMultimedia[9277]
#define sipNameNr_bytesPerLine 9290
#define sipName_bytesPerLine &sipStrings_QtMultimedia[9290]
#define sipNameNr_cameraDevice 9303
#define sipName_cameraDevice &sipStrings_QtMultimedia[9303]
#define sipNameNr_cameraFormat 9316
#define sipName_cameraFormat &sipStrings_QtMultimedia[9316]
#define sipNameNr_channelCount 9329
#define sipName_channelCount &sipStrings_QtMultimedia[9329]
#define sipNameNr_earliestTime 9342
#define sipName_earliestTime &sipStrings_QtMultimedia[9342]
#define sipNameNr_elapsedUSecs 9355
#define sipName_elapsedUSecs &sipStrings_QtMultimedia[9355]
#define sipNameNr_encodingMode 9368
#define sipName_encodingMode &sipStrings_QtMultimedia[9368]
#define sipNameNr_errorChanged 9381
#define sipName_errorChanged &sipStrings_QtMultimedia[9381]
#define sipNameNr_exposureMode 9394
#define sipName_exposureMode &sipStrings_QtMultimedia[9394]
#define sipNameNr_exposureTime 9407
#define sipName_exposureTime &sipStrings_QtMultimedia[9407]
#define sipNameNr_imageCapture 9420
#define sipName_imageCapture &sipStrings_QtMultimedia[9420]
#define sipNameNr_imageExposed 9433
#define sipName_imageExposed &sipStrings_QtMultimedia[9433]
#define sipNameNr_isContinuous 9446
#define sipName_isContinuous &sipStrings_QtMultimedia[9446]
#define sipNameNr_isFlashReady 9459
#define sipName_isFlashReady &sipStrings_QtMultimedia[9459]
#define sipNameNr_loopsChanged 9472
#define sipName_loopsChanged &sipStrings_QtMultimedia[9472]
#define sipNameNr_maxFrameRate 9485
#define sipName_maxFrameRate &sipStrings_QtMultimedia[9485]
#define sipNameNr_minFrameRate 9498
#define sipName_minFrameRate &sipStrings_QtMultimedia[9498]
#define sipNameNr_mutedChanged 9511
#define sipName_mutedChanged &sipStrings_QtMultimedia[9511]
#define sipNameNr_outputDevice 9524
#define sipName_outputDevice &sipStrings_QtMultimedia[9524]
#define sipNameNr_playbackRate 9537
#define sipName_playbackRate &sipStrings_QtMultimedia[9537]
#define sipNameNr_sampleFormat 9550
#define sipName_sampleFormat &sipStrings_QtMultimedia[9550]
#define sipNameNr_setFlashMode 9563
#define sipName_setFlashMode &sipStrings_QtMultimedia[9563]
#define sipNameNr_setFocusMode 9576
#define sipName_setFocusMode &sipStrings_QtMultimedia[9576]
#define sipNameNr_setFrameRate 9589
#define sipName_setFrameRate &sipStrings_QtMultimedia[9589]
#define sipNameNr_setFrameSize 9602
#define sipName_setFrameSize &sipStrings_QtMultimedia[9602]
#define sipNameNr_setLoopCount 9615
#define sipName_setLoopCount &sipStrings_QtMultimedia[9615]
#define sipNameNr_setProbeSize 7963
#define sipName_setProbeSize &sipStrings_QtMultimedia[7963]
#define sipNameNr_setStartTime 9628
#define sipName_setStartTime &sipStrings_QtMultimedia[9628]
#define sipNameNr_setTorchMode 9641
#define sipName_setTorchMode &sipStrings_QtMultimedia[9641]
#define sipNameNr_setVideoSink 9654
#define sipName_setVideoSink &sipStrings_QtMultimedia[9654]
#define sipNameNr_sourceDevice 9667
#define sipName_sourceDevice &sipStrings_QtMultimedia[9667]
#define sipNameNr_stateChanged 9680
#define sipName_stateChanged &sipStrings_QtMultimedia[9680]
#define sipNameNr_subtitleText 9693
#define sipName_subtitleText &sipStrings_QtMultimedia[9693]
#define sipNameNr_videoBitRate 9706
#define sipName_videoBitRate &sipStrings_QtMultimedia[9706]
#define sipNameNr_videoFormats 9719
#define sipName_videoFormats &sipStrings_QtMultimedia[9719]
#define sipNameNr_ActiveState 9732
#define sipName_ActiveState &sipStrings_QtMultimedia[9732]
#define sipNameNr_AlbumArtist 9744
#define sipName_AlbumArtist &sipStrings_QtMultimedia[9744]
#define sipNameNr_BottomToTop 9756
#define sipName_BottomToTop &sipStrings_QtMultimedia[9756]
#define sipNameNr_CameraError 9768
#define sipName_CameraError &sipStrings_QtMultimedia[9768]
#define sipNameNr_Clockwise90 9780
#define sipName_Clockwise90 &sipStrings_QtMultimedia[9780]
#define sipNameNr_Description 2596
#define sipName_Description &sipStrings_QtMultimedia[2596]
#define sipNameNr_DolbyTrueHD 9792
#define sipName_DolbyTrueHD &sipStrings_QtMultimedia[9792]
#define sipNameNr_FormatError 9804
#define sipName_FormatError &sipStrings_QtMultimedia[9804]
#define sipNameNr_Format_AYUV 9816
#define sipName_Format_AYUV &sipStrings_QtMultimedia[9816]
#define sipNameNr_Format_IMC1 9828
#define sipName_Format_IMC1 &sipStrings_QtMultimedia[9828]
#define sipNameNr_Format_IMC2 9840
#define sipName_Format_IMC2 &sipStrings_QtMultimedia[9840]
#define sipNameNr_Format_IMC3 9852
#define sipName_Format_IMC3 &sipStrings_QtMultimedia[9852]
#define sipNameNr_Format_IMC4 9864
#define sipName_Format_IMC4 &sipStrings_QtMultimedia[9864]
#define sipNameNr_Format_Jpeg 9876
#define sipName_Format_Jpeg &sipStrings_QtMultimedia[9876]
#define sipNameNr_Format_NV12 9888
#define sipName_Format_NV12 &sipStrings_QtMultimedia[9888]
#define sipNameNr_Format_NV21 9900
#define sipName_Format_NV21 &sipStrings_QtMultimedia[9900]
#define sipNameNr_Format_P010 9912
#define sipName_Format_P010 &sipStrings_QtMultimedia[9912]
#define sipNameNr_Format_P016 9924
#define sipName_Format_P016 &sipStrings_QtMultimedia[9924]
#define sipNameNr_Format_UYVY 9936
#define sipName_Format_UYVY &sipStrings_QtMultimedia[9936]
#define sipNameNr_Format_YUYV 9948
#define sipName_Format_YUYV &sipStrings_QtMultimedia[9948]
#define sipNameNr_Format_YV12 9960
#define sipName_Format_YV12 &sipStrings_QtMultimedia[9960]
#define sipNameNr_FrontCenter 5114
#define sipName_FrontCenter &sipStrings_QtMultimedia[5114]
#define sipNameNr_HighQuality 6788
#define sipName_HighQuality &sipStrings_QtMultimedia[6788]
#define sipNameNr_LoadedMedia 9972
#define sipName_LoadedMedia &sipStrings_QtMultimedia[9972]
#define sipNameNr_MediaStatus 1320
#define sipName_MediaStatus &sipStrings_QtMultimedia[1320]
#define sipNameNr_Orientation 9984
#define sipName_Orientation &sipStrings_QtMultimedia[9984]
#define sipNameNr_PausedState 9996
#define sipName_PausedState &sipStrings_QtMultimedia[9996]
#define sipNameNr_PixelFormat 513
#define sipName_PixelFormat &sipStrings_QtMultimedia[513]
#define sipNameNr_QAudioInput 10008
#define sipName_QAudioInput &sipStrings_QtMultimedia[10008]
#define sipNameNr_QVideoFrame 10020
#define sipName_QVideoFrame &sipStrings_QtMultimedia[10020]
#define sipNameNr_Rotation180 10032
#define sipName_Rotation180 &sipStrings_QtMultimedia[10032]
#define sipNameNr_Rotation270 10044
#define sipName_Rotation270 &sipStrings_QtMultimedia[10044]
#define sipNameNr_TopBackLeft 10056
#define sipName_TopBackLeft &sipStrings_QtMultimedia[10056]
#define sipNameNr_TopSideLeft 10068
#define sipName_TopSideLeft &sipStrings_QtMultimedia[10068]
#define sipNameNr_TopToBottom 10080
#define sipName_TopToBottom &sipStrings_QtMultimedia[10080]
#define sipNameNr_TrackNumber 10092
#define sipName_TrackNumber &sipStrings_QtMultimedia[10092]
#define sipNameNr_Unavailable 10104
#define sipName_Unavailable &sipStrings_QtMultimedia[10104]
#define sipNameNr_Unspecified 10116
#define sipName_Unspecified &sipStrings_QtMultimedia[10116]
#define sipNameNr_VolumeScale 2080
#define sipName_VolumeScale &sipStrings_QtMultimedia[2080]
#define sipNameNr_YCbCr_BT601 10128
#define sipName_YCbCr_BT601 &sipStrings_QtMultimedia[10128]
#define sipNameNr_YCbCr_BT709 10140
#define sipName_YCbCr_BT709 &sipStrings_QtMultimedia[10140]
#define sipNameNr_addInterval 10152
#define sipName_addInterval &sipStrings_QtMultimedia[10152]
#define sipNameNr_addMetaData 10164
#define sipName_addMetaData &sipStrings_QtMultimedia[10164]
#define sipNameNr_audioDevice 10176
#define sipName_audioDevice &sipStrings_QtMultimedia[10176]
#define sipNameNr_audioFormat 10188
#define sipName_audioFormat &sipStrings_QtMultimedia[10188]
#define sipNameNr_audioInputs 10200
#define sipName_audioInputs &sipStrings_QtMultimedia[10200]
#define sipNameNr_audioOutput 10212
#define sipName_audioOutput &sipStrings_QtMultimedia[10212]
#define sipNameNr_audioTracks 10224
#define sipName_audioTracks &sipStrings_QtMultimedia[10224]
#define sipNameNr_bufferReady 10236
#define sipName_bufferReady &sipStrings_QtMultimedia[10236]
#define sipNameNr_customEvent 10248
#define sipName_customEvent &sipStrings_QtMultimedia[10248]
#define sipNameNr_description 10260
#define sipName_description &sipStrings_QtMultimedia[10260]
#define sipNameNr_errorString 10272
#define sipName_errorString &sipStrings_QtMultimedia[10272]
#define sipNameNr_eventFilter 10284
#define sipName_eventFilter &sipStrings_QtMultimedia[10284]
#define sipNameNr_frameHeight 10296
#define sipName_frameHeight &sipStrings_QtMultimedia[10296]
#define sipNameNr_isAvailable 10308
#define sipName_isAvailable &sipStrings_QtMultimedia[10308]
#define sipNameNr_isSupported 10320
#define sipName_isSupported &sipStrings_QtMultimedia[10320]
#define sipNameNr_mappedBytes 10332
#define sipName_mappedBytes &sipStrings_QtMultimedia[10332]
#define sipNameNr_mediaFormat 10344
#define sipName_mediaFormat &sipStrings_QtMultimedia[10344]
#define sipNameNr_mediaStatus 10356
#define sipName_mediaStatus &sipStrings_QtMultimedia[10356]
#define sipNameNr_pixelFormat 10368
#define sipName_pixelFormat &sipStrings_QtMultimedia[10368]
#define sipNameNr_sampleCount 10380
#define sipName_sampleCount &sipStrings_QtMultimedia[10380]
#define sipNameNr_setAutoStop 10392
#define sipName_setAutoStop &sipStrings_QtMultimedia[10392]
#define sipNameNr_setMetaData 10404
#define sipName_setMetaData &sipStrings_QtMultimedia[10404]
#define sipNameNr_setMirrored 10416
#define sipName_setMirrored &sipStrings_QtMultimedia[10416]
#define sipNameNr_setPosition 10428
#define sipName_setPosition &sipStrings_QtMultimedia[10428]
#define sipNameNr_setRecorder 10440
#define sipName_setRecorder &sipStrings_QtMultimedia[10440]
#define sipNameNr_setRotation 10452
#define sipName_setRotation &sipStrings_QtMultimedia[10452]
#define sipNameNr_setViewport 10464
#define sipName_setViewport &sipStrings_QtMultimedia[10464]
#define sipNameNr_stringValue 10476
#define sipName_stringValue &sipStrings_QtMultimedia[10476]
#define sipNameNr_videoInputs 10488
#define sipName_videoInputs &sipStrings_QtMultimedia[10488]
#define sipNameNr_videoOutput 10500
#define sipName_videoOutput &sipStrings_QtMultimedia[10500]
#define sipNameNr_videoTracks 10512
#define sipName_videoTracks &sipStrings_QtMultimedia[10512]
#define sipNameNr_AlbumTitle 10524
#define sipName_AlbumTitle &sipStrings_QtMultimedia[10524]
#define sipNameNr_AudioCodec 1499
#define sipName_AudioCodec &sipStrings_QtMultimedia[1499]
#define sipNameNr_BackCenter 8408
#define sipName_BackCenter &sipStrings_QtMultimedia[8408]
#define sipNameNr_ColorRange 634
#define sipName_ColorRange &sipStrings_QtMultimedia[634]
#define sipNameNr_ColorSpace 221
#define sipName_ColorSpace &sipStrings_QtMultimedia[221]
#define sipNameNr_EndOfMedia 10535
#define sipName_EndOfMedia &sipStrings_QtMultimedia[10535]
#define sipNameNr_FatalError 10546
#define sipName_FatalError &sipStrings_QtMultimedia[10546]
#define sipNameNr_FileFormat 1295
#define sipName_FileFormat &sipStrings_QtMultimedia[1295]
#define sipNameNr_Format_Y16 10557
#define sipName_Format_Y16 &sipStrings_QtMultimedia[10557]
#define sipNameNr_FrontRight 5906
#define sipName_FrontRight &sipStrings_QtMultimedia[5906]
#define sipNameNr_HandleType 1843
#define sipName_HandleType &sipStrings_QtMultimedia[1843]
#define sipNameNr_LowQuality 7635
#define sipName_LowQuality &sipStrings_QtMultimedia[7635]
#define sipNameNr_MotionJPEG 10568
#define sipName_MotionJPEG &sipStrings_QtMultimedia[10568]
#define sipNameNr_Mpeg4Audio 10579
#define sipName_Mpeg4Audio &sipStrings_QtMultimedia[10579]
#define sipNameNr_QAudioSink 10590
#define sipName_QAudioSink &sipStrings_QtMultimedia[10590]
#define sipNameNr_QVideoSink 10601
#define sipName_QVideoSink &sipStrings_QtMultimedia[10601]
#define sipNameNr_Resolution 5003
#define sipName_Resolution &sipStrings_QtMultimedia[5003]
#define sipNameNr_Rotation90 10612
#define sipName_Rotation90 &sipStrings_QtMultimedia[10612]
#define sipNameNr_VideoCodec 1549
#define sipName_VideoCodec &sipStrings_QtMultimedia[1549]
#define sipNameNr_YCbCr_JPEG 10623
#define sipName_YCbCr_JPEG &sipStrings_QtMultimedia[10623]
#define sipNameNr_audioCodec 10634
#define sipName_audioCodec &sipStrings_QtMultimedia[10634]
#define sipNameNr_audioInput 10645
#define sipName_audioInput &sipStrings_QtMultimedia[10645]
#define sipNameNr_bufferSize 10656
#define sipName_bufferSize &sipStrings_QtMultimedia[10656]
#define sipNameNr_childEvent 10667
#define sipName_childEvent &sipStrings_QtMultimedia[10667]
#define sipNameNr_colorRange 10678
#define sipName_colorRange &sipStrings_QtMultimedia[10678]
#define sipNameNr_colorSpace 10689
#define sipName_colorSpace &sipStrings_QtMultimedia[10689]
#define sipNameNr_fileFormat 10700
#define sipName_fileFormat &sipStrings_QtMultimedia[10700]
#define sipNameNr_flashReady 10711
#define sipName_flashReady &sipStrings_QtMultimedia[10711]
#define sipNameNr_focusPoint 10722
#define sipName_focusPoint &sipStrings_QtMultimedia[10722]
#define sipNameNr_frameCount 10733
#define sipName_frameCount &sipStrings_QtMultimedia[10733]
#define sipNameNr_frameWidth 10744
#define sipName_frameWidth &sipStrings_QtMultimedia[10744]
#define sipNameNr_framesFree 10755
#define sipName_framesFree &sipStrings_QtMultimedia[10755]
#define sipNameNr_handleType 10766
#define sipName_handleType &sipStrings_QtMultimedia[10766]
#define sipNameNr_imageSaved 10777
#define sipName_imageSaved &sipStrings_QtMultimedia[10777]
#define sipNameNr_isDecoding 10788
#define sipName_isDecoding &sipStrings_QtMultimedia[10788]
#define sipNameNr_isMirrored 10799
#define sipName_isMirrored &sipStrings_QtMultimedia[10799]
#define sipNameNr_isReadable 10810
#define sipName_isReadable &sipStrings_QtMultimedia[10810]
#define sipNameNr_isSeekable 10821
#define sipName_isSeekable &sipStrings_QtMultimedia[10821]
#define sipNameNr_isWritable 10832
#define sipName_isWritable &sipStrings_QtMultimedia[10832]
#define sipNameNr_latestTime 10843
#define sipName_latestTime &sipStrings_QtMultimedia[10843]
#define sipNameNr_normalized 10854
#define sipName_normalized &sipStrings_QtMultimedia[10854]
#define sipNameNr_paintFlags 10865
#define sipName_paintFlags &sipStrings_QtMultimedia[10865]
#define sipNameNr_planeCount 10876
#define sipName_planeCount &sipStrings_QtMultimedia[10876]
#define sipNameNr_resolution 10887
#define sipName_resolution &sipStrings_QtMultimedia[10887]
#define sipNameNr_sampleRate 10898
#define sipName_sampleRate &sipStrings_QtMultimedia[10898]
#define sipNameNr_setEndTime 10909
#define sipName_setEndTime &sipStrings_QtMultimedia[10909]
#define sipNameNr_setQuality 10920
#define sipName_setQuality &sipStrings_QtMultimedia[10920]
#define sipNameNr_timerEvent 10931
#define sipName_timerEvent &sipStrings_QtMultimedia[10931]
#define sipNameNr_translated 10942
#define sipName_translated &sipStrings_QtMultimedia[10942]
#define sipNameNr_videoCodec 10953
#define sipName_videoCodec &sipStrings_QtMultimedia[10953]
#define sipNameNr_videoFrame 10964
#define sipName_videoFrame &sipStrings_QtMultimedia[10964]
#define sipNameNr_zoomFactor 10975
#define sipName_zoomFactor &sipStrings_QtMultimedia[10975]
#define sipNameNr_Available 6886
#define sipName_Available &sipStrings_QtMultimedia[6886]
#define sipNameNr_BackRight 9202
#define sipName_BackRight &sipStrings_QtMultimedia[9202]
#define sipNameNr_Copyright 10986
#define sipName_Copyright &sipStrings_QtMultimedia[10986]
#define sipNameNr_Direction 782
#define sipName_Direction &sipStrings_QtMultimedia[782]
#define sipNameNr_FlashAuto 10996
#define sipName_FlashAuto &sipStrings_QtMultimedia[10996]
#define sipNameNr_FlashMode 4662
#define sipName_FlashMode &sipStrings_QtMultimedia[4662]
#define sipNameNr_FocusMode 4681
#define sipName_FocusMode &sipStrings_QtMultimedia[4681]
#define sipNameNr_Format_Y8 11006
#define sipName_Format_Y8 &sipStrings_QtMultimedia[11006]
#define sipNameNr_FrontFace 11016
#define sipName_FrontFace &sipStrings_QtMultimedia[11016]
#define sipNameNr_FrontLeft 6518
#define sipName_FrontLeft &sipStrings_QtMultimedia[6518]
#define sipNameNr_IdleState 11026
#define sipName_IdleState &sipStrings_QtMultimedia[11026]
#define sipNameNr_MediaType 11036
#define sipName_MediaType &sipStrings_QtMultimedia[11036]
#define sipNameNr_NotMapped 11046
#define sipName_NotMapped &sipStrings_QtMultimedia[11046]
#define sipNameNr_OpenError 11056
#define sipName_OpenError &sipStrings_QtMultimedia[11056]
#define sipNameNr_PaintFlag 116
#define sipName_PaintFlag &sipStrings_QtMultimedia[116]
#define sipNameNr_Publisher 11066
#define sipName_Publisher &sipStrings_QtMultimedia[11066]
#define sipNameNr_QuickTime 11076
#define sipName_QuickTime &sipStrings_QtMultimedia[11076]
#define sipNameNr_ReadWrite 11086
#define sipName_ReadWrite &sipStrings_QtMultimedia[11086]
#define sipNameNr_Rotation0 11096
#define sipName_Rotation0 &sipStrings_QtMultimedia[11096]
#define sipNameNr_SideRight 9228
#define sipName_SideRight &sipStrings_QtMultimedia[9228]
#define sipNameNr_TopCenter 11106
#define sipName_TopCenter &sipStrings_QtMultimedia[11106]
#define sipNameNr_TorchAuto 11116
#define sipName_TorchAuto &sipStrings_QtMultimedia[11116]
#define sipNameNr_TorchMode 4700
#define sipName_TorchMode &sipStrings_QtMultimedia[4700]
#define sipNameNr_WriteOnly 11126
#define sipName_WriteOnly &sipStrings_QtMultimedia[11126]
#define sipNameNr_byteCount 11136
#define sipName_byteCount &sipStrings_QtMultimedia[11136]
#define sipNameNr_bytesFree 11146
#define sipName_bytesFree &sipStrings_QtMultimedia[11146]
#define sipNameNr_constData 11156
#define sipName_constData &sipStrings_QtMultimedia[11156]
#define sipNameNr_flashMode 11166
#define sipName_flashMode &sipStrings_QtMultimedia[11166]
#define sipNameNr_focusMode 11176
#define sipName_focusMode &sipStrings_QtMultimedia[11176]
#define sipNameNr_frameRate 11186
#define sipName_frameRate &sipStrings_QtMultimedia[11186]
#define sipNameNr_frameSize 11196
#define sipName_frameSize &sipStrings_QtMultimedia[11196]
#define sipNameNr_intervals 11206
#define sipName_intervals &sipStrings_QtMultimedia[11206]
#define sipNameNr_isDefault 11216
#define sipName_isDefault &sipStrings_QtMultimedia[11216]
#define sipNameNr_isPlaying 11226
#define sipName_isPlaying &sipStrings_QtMultimedia[11226]
#define sipNameNr_loopCount 11236
#define sipName_loopCount &sipStrings_QtMultimedia[11236]
#define sipNameNr_probeSize 11246
#define sipName_probeSize &sipStrings_QtMultimedia[11246]
#define sipNameNr_setActive 11256
#define sipName_setActive &sipStrings_QtMultimedia[11256]
#define sipNameNr_setCamera 11266
#define sipName_setCamera &sipStrings_QtMultimedia[11266]
#define sipNameNr_setDevice 11276
#define sipName_setDevice &sipStrings_QtMultimedia[11276]
#define sipNameNr_setScreen 11286
#define sipName_setScreen &sipStrings_QtMultimedia[11286]
#define sipNameNr_setSource 11296
#define sipName_setSource &sipStrings_QtMultimedia[11296]
#define sipNameNr_setVolume 11306
#define sipName_setVolume &sipStrings_QtMultimedia[11306]
#define sipNameNr_setWindow 11316
#define sipName_setWindow &sipStrings_QtMultimedia[11316]
#define sipNameNr_sourceUrl 11326
#define sipName_sourceUrl &sipStrings_QtMultimedia[11326]
#define sipNameNr_startTime 11336
#define sipName_startTime &sipStrings_QtMultimedia[11336]
#define sipNameNr_torchMode 11346
#define sipName_torchMode &sipStrings_QtMultimedia[11346]
#define sipNameNr_videoSink 11356
#define sipName_videoSink &sipStrings_QtMultimedia[11356]
#define sipNameNr_videoSize 11366
#define sipName_videoSize &sipStrings_QtMultimedia[11366]
#define sipNameNr_AlwaysOn 11376
#define sipName_AlwaysOn &sipStrings_QtMultimedia[11376]
#define sipNameNr_BackFace 11385
#define sipName_BackFace &sipStrings_QtMultimedia[11385]
#define sipNameNr_BackLeft 10059
#define sipName_BackLeft &sipStrings_QtMultimedia[10059]
#define sipNameNr_Composer 11394
#define sipName_Composer &sipStrings_QtMultimedia[11394]
#define sipNameNr_Duration 5621
#define sipName_Duration &sipStrings_QtMultimedia[5621]
#define sipNameNr_FlashOff 11403
#define sipName_FlashOff &sipStrings_QtMultimedia[11403]
#define sipNameNr_Infinite 11412
#define sipName_Infinite &sipStrings_QtMultimedia[11412]
#define sipNameNr_Interval 1349
#define sipName_Interval &sipStrings_QtMultimedia[1349]
#define sipNameNr_Language 11421
#define sipName_Language &sipStrings_QtMultimedia[11421]
#define sipNameNr_Matroska 11430
#define sipName_Matroska &sipStrings_QtMultimedia[11430]
#define sipNameNr_NoHandle 11439
#define sipName_NoHandle &sipStrings_QtMultimedia[11439]
#define sipNameNr_NotFound 11448
#define sipName_NotFound &sipStrings_QtMultimedia[11448]
#define sipNameNr_Playback 11457
#define sipName_Playback &sipStrings_QtMultimedia[11457]
#define sipNameNr_Position 188
#define sipName_Position &sipStrings_QtMultimedia[188]
#define sipNameNr_ReadOnly 11466
#define sipName_ReadOnly &sipStrings_QtMultimedia[11466]
#define sipNameNr_Rotation 5369
#define sipName_Rotation &sipStrings_QtMultimedia[5369]
#define sipNameNr_SideLeft 10071
#define sipName_SideLeft &sipStrings_QtMultimedia[10071]
#define sipNameNr_TorchOff 11475
#define sipName_TorchOff &sipStrings_QtMultimedia[11475]
#define sipNameNr___iadd__ 11484
#define sipName___iadd__ &sipStrings_QtMultimedia[11484]
#define sipNameNr___isub__ 11493
#define sipName___isub__ &sipStrings_QtMultimedia[11493]
#define sipNameNr_autoStop 11502
#define sipName_autoStop &sipStrings_QtMultimedia[11502]
#define sipNameNr_contains 11511
#define sipName_contains &sipStrings_QtMultimedia[11511]
#define sipNameNr_duration 11520
#define sipName_duration &sipStrings_QtMultimedia[11520]
#define sipNameNr_finished 11529
#define sipName_finished &sipStrings_QtMultimedia[11529]
#define sipNameNr_hasAudio 11538
#define sipName_hasAudio &sipStrings_QtMultimedia[11538]
#define sipNameNr_hasVideo 11547
#define sipName_hasVideo &sipStrings_QtMultimedia[11547]
#define sipNameNr_isActive 11556
#define sipName_isActive &sipStrings_QtMultimedia[11556]
#define sipNameNr_isLoaded 11565
#define sipName_isLoaded &sipStrings_QtMultimedia[11565]
#define sipNameNr_isMapped 11574
#define sipName_isMapped &sipStrings_QtMultimedia[11574]
#define sipNameNr_isNormal 11583
#define sipName_isNormal &sipStrings_QtMultimedia[11583]
#define sipNameNr_location 11592
#define sipName_location &sipStrings_QtMultimedia[11592]
#define sipNameNr_metaData 11601
#define sipName_metaData &sipStrings_QtMultimedia[11601]
#define sipNameNr_mimeType 11610
#define sipName_mimeType &sipStrings_QtMultimedia[11610]
#define sipNameNr_mirrored 11619
#define sipName_mirrored &sipStrings_QtMultimedia[11619]
#define sipNameNr_position 11628
#define sipName_position &sipStrings_QtMultimedia[11628]
#define sipNameNr_recorder 11637
#define sipName_recorder &sipStrings_QtMultimedia[11637]
#define sipNameNr_rotation 11646
#define sipName_rotation &sipStrings_QtMultimedia[11646]
#define sipNameNr_setLoops 11655
#define sipName_setLoops &sipStrings_QtMultimedia[11655]
#define sipNameNr_setMuted 11664
#define sipName_setMuted &sipStrings_QtMultimedia[11664]
#define sipNameNr_viewport 11673
#define sipName_viewport &sipStrings_QtMultimedia[11673]
#define sipNameNr_Comment 11682
#define sipName_Comment &sipStrings_QtMultimedia[11682]
#define sipNameNr_Feature 6045
#define sipName_Feature &sipStrings_QtMultimedia[6045]
#define sipNameNr_FlashOn 11690
#define sipName_FlashOn &sipStrings_QtMultimedia[11690]
#define sipNameNr_IOError 11698
#define sipName_IOError &sipStrings_QtMultimedia[11698]
#define sipNameNr_Loading 11706
#define sipName_Loading &sipStrings_QtMultimedia[11706]
#define sipNameNr_MapMode 3095
#define sipName_MapMode &sipStrings_QtMultimedia[3095]
#define sipNameNr_NoError 11714
#define sipName_NoError &sipStrings_QtMultimedia[11714]
#define sipNameNr_NoFlags 11722
#define sipName_NoFlags &sipStrings_QtMultimedia[11722]
#define sipNameNr_NoMedia 11730
#define sipName_NoMedia &sipStrings_QtMultimedia[11730]
#define sipNameNr_QCamera 11738
#define sipName_QCamera &sipStrings_QtMultimedia[11738]
#define sipNameNr_QtVideo 11746
#define sipName_QtVideo &sipStrings_QtMultimedia[11746]
#define sipNameNr_Quality 1822
#define sipName_Quality &sipStrings_QtMultimedia[1822]
#define sipNameNr_TorchOn 11754
#define sipName_TorchOn &sipStrings_QtMultimedia[11754]
#define sipNameNr_Unknown 2424
#define sipName_Unknown &sipStrings_QtMultimedia[2424]
#define sipNameNr___add__ 11762
#define sipName___add__ &sipStrings_QtMultimedia[11762]
#define sipNameNr___sub__ 11770
#define sipName___sub__ &sipStrings_QtMultimedia[11770]
#define sipNameNr_capture 11778
#define sipName_capture &sipStrings_QtMultimedia[11778]
#define sipNameNr_endTime 11786
#define sipName_endTime &sipStrings_QtMultimedia[11786]
#define sipNameNr_isEmpty 11794
#define sipName_isEmpty &sipStrings_QtMultimedia[11794]
#define sipNameNr_isMuted 11802
#define sipName_isMuted &sipStrings_QtMultimedia[11802]
#define sipNameNr_isValid 11810
#define sipName_isValid &sipStrings_QtMultimedia[11810]
#define sipNameNr_keyType 11818
#define sipName_keyType &sipStrings_QtMultimedia[11818]
#define sipNameNr_mapMode 11826
#define sipName_mapMode &sipStrings_QtMultimedia[11826]
#define sipNameNr_quality 11834
#define sipName_quality &sipStrings_QtMultimedia[11834]
#define sipNameNr_suspend 11842
#define sipName_suspend &sipStrings_QtMultimedia[11842]
#define sipNameNr_toImage 11850
#define sipName_toImage &sipStrings_QtMultimedia[11850]
#define sipNameNr_Author 11858
#define sipName_Author &sipStrings_QtMultimedia[11858]
#define sipNameNr_Decode 11865
#define sipName_Decode &sipStrings_QtMultimedia[11865]
#define sipNameNr_Encode 11872
#define sipName_Encode &sipStrings_QtMultimedia[11872]
#define sipNameNr_Output 3390
#define sipName_Output &sipStrings_QtMultimedia[3390]
#define sipNameNr_QAudio 11879
#define sipName_QAudio &sipStrings_QtMultimedia[11879]
#define sipNameNr_Status 1325
#define sipName_Status &sipStrings_QtMultimedia[1325]
#define sipNameNr_Theora 11886
#define sipName_Theora &sipStrings_QtMultimedia[11886]
#define sipNameNr_Vorbis 11893
#define sipName_Vorbis &sipStrings_QtMultimedia[11893]
#define sipNameNr___eq__ 11900
#define sipName___eq__ &sipStrings_QtMultimedia[11900]
#define sipNameNr___ge__ 11907
#define sipName___ge__ &sipStrings_QtMultimedia[11907]
#define sipNameNr___gt__ 11914
#define sipName___gt__ &sipStrings_QtMultimedia[11914]
#define sipNameNr___le__ 11921
#define sipName___le__ &sipStrings_QtMultimedia[11921]
#define sipNameNr___lt__ 11928
#define sipName___lt__ &sipStrings_QtMultimedia[11928]
#define sipNameNr___ne__ 11935
#define sipName___ne__ &sipStrings_QtMultimedia[11935]
#define sipNameNr_camera 11942
#define sipName_camera &sipStrings_QtMultimedia[11942]
#define sipNameNr_detach 11949
#define sipName_detach &sipStrings_QtMultimedia[11949]
#define sipNameNr_device 11956
#define sipName_device &sipStrings_QtMultimedia[11956]
#define sipNameNr_format 11963
#define sipName_format &sipStrings_QtMultimedia[11963]
#define sipNameNr_height 11970
#define sipName_height &sipStrings_QtMultimedia[11970]
#define sipNameNr_insert 11977
#define sipName_insert &sipStrings_QtMultimedia[11977]
#define sipNameNr_isNull 11984
#define sipName_isNull &sipStrings_QtMultimedia[11984]
#define sipNameNr_parent 11991
#define sipName_parent &sipStrings_QtMultimedia[11991]
#define sipNameNr_record 11998
#define sipName_record &sipStrings_QtMultimedia[11998]
#define sipNameNr_resume 12005
#define sipName_resume &sipStrings_QtMultimedia[12005]
#define sipNameNr_screen 12012
#define sipName_screen &sipStrings_QtMultimedia[12012]
#define sipNameNr_source 12019
#define sipName_source &sipStrings_QtMultimedia[12019]
#define sipNameNr_status 12026
#define sipName_status &sipStrings_QtMultimedia[12026]
#define sipNameNr_volume 12033
#define sipName_volume &sipStrings_QtMultimedia[12033]
#define sipNameNr_window 12040
#define sipName_window &sipStrings_QtMultimedia[12040]
#define sipNameNr_zoomTo 12047
#define sipName_zoomTo &sipStrings_QtMultimedia[12047]
#define sipNameNr_Error 1429
#define sipName_Error &sipStrings_QtMultimedia[1429]
#define sipNameNr_Float 12054
#define sipName_Float &sipStrings_QtMultimedia[12054]
#define sipNameNr_Genre 12060
#define sipName_Genre &sipStrings_QtMultimedia[12060]
#define sipNameNr_Input 4298
#define sipName_Input &sipStrings_QtMultimedia[4298]
#define sipNameNr_Int16 12066
#define sipName_Int16 &sipStrings_QtMultimedia[12066]
#define sipNameNr_Int32 12072
#define sipName_Int32 &sipStrings_QtMultimedia[12072]
#define sipNameNr_Loops 3818
#define sipName_Loops &sipStrings_QtMultimedia[3818]
#define sipNameNr_MPEG1 12078
#define sipName_MPEG1 &sipStrings_QtMultimedia[12078]
#define sipNameNr_MPEG2 12084
#define sipName_MPEG2 &sipStrings_QtMultimedia[12084]
#define sipNameNr_MPEG4 12090
#define sipName_MPEG4 &sipStrings_QtMultimedia[12090]
#define sipNameNr_None_ 12096
#define sipName_None_ &sipStrings_QtMultimedia[12096]
#define sipNameNr_Ready 9466
#define sipName_Ready &sipStrings_QtMultimedia[9466]
#define sipNameNr_State 609
#define sipName_State &sipStrings_QtMultimedia[609]
#define sipNameNr_Title 10529
#define sipName_Title &sipStrings_QtMultimedia[10529]
#define sipNameNr_UInt8 12102
#define sipName_UInt8 &sipStrings_QtMultimedia[12102]
#define sipNameNr_clear 12108
#define sipName_clear &sipStrings_QtMultimedia[12108]
#define sipNameNr_error 12114
#define sipName_error &sipStrings_QtMultimedia[12114]
#define sipNameNr_event 12120
#define sipName_event &sipStrings_QtMultimedia[12120]
#define sipNameNr_loops 12126
#define sipName_loops &sipStrings_QtMultimedia[12126]
#define sipNameNr_paint 12132
#define sipName_paint &sipStrings_QtMultimedia[12132]
#define sipNameNr_pause 12138
#define sipName_pause &sipStrings_QtMultimedia[12138]
#define sipNameNr_reset 12144
#define sipName_reset &sipStrings_QtMultimedia[12144]
#define sipNameNr_start 12150
#define sipName_start &sipStrings_QtMultimedia[12150]
#define sipNameNr_state 12156
#define sipName_state &sipStrings_QtMultimedia[12156]
#define sipNameNr_unmap 12162
#define sipName_unmap &sipStrings_QtMultimedia[12162]
#define sipNameNr_value 12168
#define sipName_value &sipStrings_QtMultimedia[12168]
#define sipNameNr_width 12174
#define sipName_width &sipStrings_QtMultimedia[12174]
#define sipNameNr_ALAC 12180
#define sipName_ALAC &sipStrings_QtMultimedia[12180]
#define sipNameNr_Date 12185
#define sipName_Date &sipStrings_QtMultimedia[12185]
#define sipNameNr_EAC3 12190
#define sipName_EAC3 &sipStrings_QtMultimedia[12190]
#define sipNameNr_FLAC 12195
#define sipName_FLAC &sipStrings_QtMultimedia[12195]
#define sipNameNr_H264 12200
#define sipName_H264 &sipStrings_QtMultimedia[12200]
#define sipNameNr_H265 12205
#define sipName_H265 &sipStrings_QtMultimedia[12205]
#define sipNameNr_JPEG 10574
#define sipName_JPEG &sipStrings_QtMultimedia[10574]
#define sipNameNr_LFE2 12210
#define sipName_LFE2 &sipStrings_QtMultimedia[12210]
#define sipNameNr_Loop 4724
#define sipName_Loop &sipStrings_QtMultimedia[4724]
#define sipNameNr_Mode 729
#define sipName_Mode &sipStrings_QtMultimedia[729]
#define sipNameNr_Null 11986
#define sipName_Null &sipStrings_QtMultimedia[11986]
#define sipNameNr_Once 12215
#define sipName_Once &sipStrings_QtMultimedia[12215]
#define sipNameNr_Opus 12220
#define sipName_Opus &sipStrings_QtMultimedia[12220]
#define sipNameNr_Tiff 12225
#define sipName_Tiff &sipStrings_QtMultimedia[12225]
#define sipNameNr_Wave 12230
#define sipName_Wave &sipStrings_QtMultimedia[12230]
#define sipNameNr_WebM 12235
#define sipName_WebM &sipStrings_QtMultimedia[12235]
#define sipNameNr_WebP 12240
#define sipName_WebP &sipStrings_QtMultimedia[12240]
#define sipNameNr_bits 12245
#define sipName_bits &sipStrings_QtMultimedia[12245]
#define sipNameNr_data 12250
#define sipName_data &sipStrings_QtMultimedia[12250]
#define sipNameNr_keys 12255
#define sipName_keys &sipStrings_QtMultimedia[12255]
#define sipNameNr_mode 12260
#define sipName_mode &sipStrings_QtMultimedia[12260]
#define sipNameNr_play 12265
#define sipName_play &sipStrings_QtMultimedia[12265]
#define sipNameNr_read 12270
#define sipName_read &sipStrings_QtMultimedia[12270]
#define sipNameNr_size 12275
#define sipName_size &sipStrings_QtMultimedia[12275]
#define sipNameNr_stop 12280
#define sipName_stop &sipStrings_QtMultimedia[12280]
#define sipNameNr_swap 12285
#define sipName_swap &sipStrings_QtMultimedia[12285]
#define sipNameNr_AAC 12290
#define sipName_AAC &sipStrings_QtMultimedia[12290]
#define sipNameNr_AC3 12191
#define sipName_AC3 &sipStrings_QtMultimedia[12191]
#define sipNameNr_AV1 12294
#define sipName_AV1 &sipStrings_QtMultimedia[12294]
#define sipNameNr_AVI 12298
#define sipName_AVI &sipStrings_QtMultimedia[12298]
#define sipNameNr_Key 3780
#define sipName_Key &sipStrings_QtMultimedia[3780]
#define sipNameNr_LFE 12302
#define sipName_LFE &sipStrings_QtMultimedia[12302]
#define sipNameNr_MP3 12306
#define sipName_MP3 &sipStrings_QtMultimedia[12306]
#define sipNameNr_Ogg 12310
#define sipName_Ogg &sipStrings_QtMultimedia[12310]
#define sipNameNr_PNG 12314
#define sipName_PNG &sipStrings_QtMultimedia[12314]
#define sipNameNr_Url 11332
#define sipName_Url &sipStrings_QtMultimedia[11332]
#define sipNameNr_VP8 12318
#define sipName_VP8 &sipStrings_QtMultimedia[12318]
#define sipNameNr_VP9 12322
#define sipName_VP9 &sipStrings_QtMultimedia[12322]
#define sipNameNr_WMA 12326
#define sipName_WMA &sipStrings_QtMultimedia[12326]
#define sipNameNr_WMV 12330
#define sipName_WMV &sipStrings_QtMultimedia[12330]
#define sipNameNr_end 11846
#define sipName_end &sipStrings_QtMultimedia[11846]
#define sipNameNr_map 12164
#define sipName_map &sipStrings_QtMultimedia[12164]
#define sipNameNr_id 7463
#define sipName_id &sipStrings_QtMultimedia[7463]

#define sipMalloc                   sipAPI_QtMultimedia->api_malloc
#define sipFree                     sipAPI_QtMultimedia->api_free
#define sipBuildResult              sipAPI_QtMultimedia->api_build_result
#define sipCallMethod               sipAPI_QtMultimedia->api_call_method
#define sipCallProcedureMethod      sipAPI_QtMultimedia->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtMultimedia->api_call_error_handler
#define sipParseResultEx            sipAPI_QtMultimedia->api_parse_result_ex
#define sipParseResult              sipAPI_QtMultimedia->api_parse_result
#define sipParseArgs                sipAPI_QtMultimedia->api_parse_args
#define sipParseKwdArgs             sipAPI_QtMultimedia->api_parse_kwd_args
#define sipParsePair                sipAPI_QtMultimedia->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtMultimedia->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtMultimedia->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtMultimedia->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtMultimedia->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtMultimedia->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtMultimedia->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtMultimedia->api_add_exception
#define sipNoFunction               sipAPI_QtMultimedia->api_no_function
#define sipNoMethod                 sipAPI_QtMultimedia->api_no_method
#define sipAbstractMethod           sipAPI_QtMultimedia->api_abstract_method
#define sipBadClass                 sipAPI_QtMultimedia->api_bad_class
#define sipBadCatcherResult         sipAPI_QtMultimedia->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtMultimedia->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtMultimedia->api_bad_operator_arg
#define sipTrace                    sipAPI_QtMultimedia->api_trace
#define sipTransferBack             sipAPI_QtMultimedia->api_transfer_back
#define sipTransferTo               sipAPI_QtMultimedia->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtMultimedia->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtMultimedia->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtMultimedia->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtMultimedia->api_voidptr_type
#define sipGetPyObject              sipAPI_QtMultimedia->api_get_pyobject
#define sipGetAddress               sipAPI_QtMultimedia->api_get_address
#define sipGetMixinAddress          sipAPI_QtMultimedia->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtMultimedia->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtMultimedia->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtMultimedia->api_call_hook
#define sipEndThread                sipAPI_QtMultimedia->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtMultimedia->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtMultimedia->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtMultimedia->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtMultimedia->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtMultimedia->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtMultimedia->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtMultimedia->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtMultimedia->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtMultimedia->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtMultimedia->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtMultimedia->api_convert_to_bool
#define sipReleaseType              sipAPI_QtMultimedia->api_release_type
#define sipConvertFromType          sipAPI_QtMultimedia->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtMultimedia->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtMultimedia->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtMultimedia->api_convert_from_enum
#define sipGetState                 sipAPI_QtMultimedia->api_get_state
#define sipExportSymbol             sipAPI_QtMultimedia->api_export_symbol
#define sipImportSymbol             sipAPI_QtMultimedia->api_import_symbol
#define sipFindType                 sipAPI_QtMultimedia->api_find_type
#define sipBytes_AsChar             sipAPI_QtMultimedia->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtMultimedia->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtMultimedia->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtMultimedia->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtMultimedia->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtMultimedia->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtMultimedia->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtMultimedia->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtMultimedia->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtMultimedia->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtMultimedia->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtMultimedia->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtMultimedia->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtMultimedia->api_get_reference
#define sipKeepReference            sipAPI_QtMultimedia->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtMultimedia->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtMultimedia->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtMultimedia->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtMultimedia->api_type_scope
#define sipResolveTypedef           sipAPI_QtMultimedia->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtMultimedia->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtMultimedia->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtMultimedia->api_init_mixin
#define sipExportModule             sipAPI_QtMultimedia->api_export_module
#define sipInitModule               sipAPI_QtMultimedia->api_init_module
#define sipGetInterpreter           sipAPI_QtMultimedia->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtMultimedia->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtMultimedia->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtMultimedia->api_py_type_dict
#define sipPyTypeName               sipAPI_QtMultimedia->api_py_type_name
#define sipGetCFunction             sipAPI_QtMultimedia->api_get_c_function
#define sipGetMethod                sipAPI_QtMultimedia->api_get_method
#define sipFromMethod               sipAPI_QtMultimedia->api_from_method
#define sipGetDate                  sipAPI_QtMultimedia->api_get_date
#define sipFromDate                 sipAPI_QtMultimedia->api_from_date
#define sipGetDateTime              sipAPI_QtMultimedia->api_get_datetime
#define sipFromDateTime             sipAPI_QtMultimedia->api_from_datetime
#define sipGetTime                  sipAPI_QtMultimedia->api_get_time
#define sipFromTime                 sipAPI_QtMultimedia->api_from_time
#define sipIsUserType               sipAPI_QtMultimedia->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtMultimedia->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtMultimedia->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtMultimedia->api_unicode_write
#define sipUnicodeData              sipAPI_QtMultimedia->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtMultimedia->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtMultimedia->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtMultimedia->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtMultimedia->api_is_derived_class
#define sipGetUserObject            sipAPI_QtMultimedia->api_get_user_object
#define sipSetUserObject            sipAPI_QtMultimedia->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtMultimedia->api_register_event_handler
#define sipConvertToArray           sipAPI_QtMultimedia->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtMultimedia->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtMultimedia->api_enable_gc
#define sipPrintObject              sipAPI_QtMultimedia->api_print_object
#define sipLong_AsChar              sipAPI_QtMultimedia->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtMultimedia->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtMultimedia->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtMultimedia->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtMultimedia->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtMultimedia->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtMultimedia->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtMultimedia->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtMultimedia->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtMultimedia->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtMultimedia->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtMultimedia->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtMultimedia->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtMultimedia->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtMultimedia->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtMultimedia->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtMultimedia->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtMultimedia->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtMultimedia->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtMultimedia->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtMultimedia->api_release_type_us
#define sipIsPyMethod               sipAPI_QtMultimedia->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtMultimedia[];

#define sipType_QtVideo sipExportedTypes_QtMultimedia[96]

#define sipType_QtVideo_Rotation sipExportedTypes_QtMultimedia[97]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QtVideo;

#define sipType_QAudio sipExportedTypes_QtMultimedia[0]

#define sipType_QAudio_VolumeScale sipExportedTypes_QtMultimedia[3]

#define sipType_QAudio_State sipExportedTypes_QtMultimedia[2]

#define sipType_QAudio_Error sipExportedTypes_QtMultimedia[1]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudio;

#define sipType_QAudioBuffer sipExportedTypes_QtMultimedia[4]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioBuffer;

#define sipType_QAudioBufferInput sipExportedTypes_QtMultimedia[5]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioBufferInput;

#define sipType_QAudioBufferOutput sipExportedTypes_QtMultimedia[6]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioBufferOutput;

#define sipType_QAudioDecoder sipExportedTypes_QtMultimedia[7]

#define sipType_QAudioDecoder_Error sipExportedTypes_QtMultimedia[8]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDecoder;

#define sipType_QAudioDevice sipExportedTypes_QtMultimedia[9]

#define sipType_QAudioDevice_Mode sipExportedTypes_QtMultimedia[10]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDevice;

#define sipType_QAudioFormat sipExportedTypes_QtMultimedia[11]

#define sipType_QAudioFormat_SampleFormat sipExportedTypes_QtMultimedia[14]

#define sipType_QAudioFormat_ChannelConfig sipExportedTypes_QtMultimedia[13]

#define sipType_QAudioFormat_AudioChannelPosition sipExportedTypes_QtMultimedia[12]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioFormat;

#define sipType_QAudioInput sipExportedTypes_QtMultimedia[15]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioInput;

#define sipType_QAudioOutput sipExportedTypes_QtMultimedia[16]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioOutput;

#define sipType_QAudioSink sipExportedTypes_QtMultimedia[17]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioSink;

#define sipType_QAudioSource sipExportedTypes_QtMultimedia[18]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioSource;

#define sipType_QCamera sipExportedTypes_QtMultimedia[19]

#define sipType_QCamera_Feature sipExportedTypes_QtMultimedia[22]

#define sipType_QCamera_WhiteBalanceMode sipExportedTypes_QtMultimedia[26]

#define sipType_QCamera_ExposureMode sipExportedTypes_QtMultimedia[21]

#define sipType_QCamera_TorchMode sipExportedTypes_QtMultimedia[25]

#define sipType_QCamera_FlashMode sipExportedTypes_QtMultimedia[23]

#define sipType_QCamera_FocusMode sipExportedTypes_QtMultimedia[24]

#define sipType_QCamera_Error sipExportedTypes_QtMultimedia[20]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCamera;

#define sipType_QCameraFormat sipExportedTypes_QtMultimedia[29]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFormat;

#define sipType_QCameraDevice sipExportedTypes_QtMultimedia[27]

#define sipType_QCameraDevice_Position sipExportedTypes_QtMultimedia[28]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraDevice;

#define sipType_QCapturableWindow sipExportedTypes_QtMultimedia[30]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCapturableWindow;

#define sipType_QImageCapture sipExportedTypes_QtMultimedia[33]

#define sipType_QImageCapture_FileFormat sipExportedTypes_QtMultimedia[35]

#define sipType_QImageCapture_Quality sipExportedTypes_QtMultimedia[36]

#define sipType_QImageCapture_Error sipExportedTypes_QtMultimedia[34]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QImageCapture;

#define sipType_QMediaCaptureSession sipExportedTypes_QtMultimedia[49]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaCaptureSession;

#define sipType_QMediaDevices sipExportedTypes_QtMultimedia[50]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaDevices;

#define sipType_QMediaFormat sipExportedTypes_QtMultimedia[51]

#define sipType_QMediaFormat_ResolveFlags sipExportedTypes_QtMultimedia[55]

#define sipType_QMediaFormat_ConversionMode sipExportedTypes_QtMultimedia[53]

#define sipType_QMediaFormat_VideoCodec sipExportedTypes_QtMultimedia[56]

#define sipType_QMediaFormat_AudioCodec sipExportedTypes_QtMultimedia[52]

#define sipType_QMediaFormat_FileFormat sipExportedTypes_QtMultimedia[54]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaFormat;

#define sipType_QMediaMetaData sipExportedTypes_QtMultimedia[57]

#define sipType_QMediaMetaData_Key sipExportedTypes_QtMultimedia[58]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaMetaData;

#define sipType_QMediaPlayer sipExportedTypes_QtMultimedia[59]

#define sipType_QMediaPlayer_PitchCompensationAvailability sipExportedTypes_QtMultimedia[63]

#define sipType_QMediaPlayer_Loops sipExportedTypes_QtMultimedia[61]

#define sipType_QMediaPlayer_Error sipExportedTypes_QtMultimedia[60]

#define sipType_QMediaPlayer_MediaStatus sipExportedTypes_QtMultimedia[62]

#define sipType_QMediaPlayer_PlaybackState sipExportedTypes_QtMultimedia[64]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayer;

#define sipType_QMediaRecorder sipExportedTypes_QtMultimedia[65]

#define sipType_QMediaRecorder_Error sipExportedTypes_QtMultimedia[67]

#define sipType_QMediaRecorder_RecorderState sipExportedTypes_QtMultimedia[69]

#define sipType_QMediaRecorder_EncodingMode sipExportedTypes_QtMultimedia[66]

#define sipType_QMediaRecorder_Quality sipExportedTypes_QtMultimedia[68]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorder;

#define sipType_QMediaTimeRange sipExportedTypes_QtMultimedia[70]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaTimeRange;

#define sipType_QMediaTimeRange_Interval sipExportedTypes_QtMultimedia[71]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaTimeRange_Interval;

#define sipType_QPlaybackOptions sipExportedTypes_QtMultimedia[72]

#define sipType_QPlaybackOptions_PlaybackIntent sipExportedTypes_QtMultimedia[73]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QPlaybackOptions;

#define sipType_QScreenCapture sipExportedTypes_QtMultimedia[74]

#define sipType_QScreenCapture_Error sipExportedTypes_QtMultimedia[75]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QScreenCapture;

#define sipType_QSoundEffect sipExportedTypes_QtMultimedia[76]

#define sipType_QSoundEffect_Status sipExportedTypes_QtMultimedia[78]

#define sipType_QSoundEffect_Loop sipExportedTypes_QtMultimedia[77]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QSoundEffect;

#define sipType_QVideoFrame sipExportedTypes_QtMultimedia[79]

#define sipType_QVideoFrame_RotationAngle sipExportedTypes_QtMultimedia[84]

#define sipType_QVideoFrame_MapMode sipExportedTypes_QtMultimedia[81]

#define sipType_QVideoFrame_HandleType sipExportedTypes_QtMultimedia[80]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFrame;

#define sipType_QVideoFrame_PaintOptions sipExportedTypes_QtMultimedia[82]

#define sipType_QVideoFrame_PaintOptions_PaintFlag sipExportedTypes_QtMultimedia[83]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFrame_PaintOptions;

#define sipType_QVideoFrameFormat sipExportedTypes_QtMultimedia[85]

#define sipType_QVideoFrameFormat_ColorRange sipExportedTypes_QtMultimedia[86]

#define sipType_QVideoFrameFormat_ColorTransfer sipExportedTypes_QtMultimedia[88]

#define sipType_QVideoFrameFormat_ColorSpace sipExportedTypes_QtMultimedia[87]

#define sipType_QVideoFrameFormat_YCbCrColorSpace sipExportedTypes_QtMultimedia[91]

#define sipType_QVideoFrameFormat_Direction sipExportedTypes_QtMultimedia[89]

#define sipType_QVideoFrameFormat_PixelFormat sipExportedTypes_QtMultimedia[90]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFrameFormat;

#define sipType_QVideoFrameInput sipExportedTypes_QtMultimedia[92]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFrameInput;

#define sipType_QVideoSink sipExportedTypes_QtMultimedia[93]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoSink;

#define sipType_QWindowCapture sipExportedTypes_QtMultimedia[94]

#define sipType_QWindowCapture_Error sipExportedTypes_QtMultimedia[95]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QWindowCapture;

#define sipType_QList_0100QCapturableWindow sipExportedTypes_QtMultimedia[41]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCapturableWindow;

#define sipType_QList_0100QMediaTimeRange_Interval sipExportedTypes_QtMultimedia[48]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaTimeRange_Interval;

#define sipType_QList_0100QMediaMetaData sipExportedTypes_QtMultimedia[47]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaMetaData;

#define sipType_QList_0100QMediaMetaData_Key sipExportedTypes_QtMultimedia[46]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaMetaData_Key;

#define sipType_QList_0100QCameraDevice sipExportedTypes_QtMultimedia[39]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCameraDevice;

#define sipType_QList_0100QAudioDevice sipExportedTypes_QtMultimedia[37]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudioDevice;

#define sipType_QList_0100QCameraFormat sipExportedTypes_QtMultimedia[40]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCameraFormat;

#define sipType_QFlags_0100QVideoFrame_PaintOptions_PaintFlag sipExportedTypes_QtMultimedia[32]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QFlags_0100QVideoFrame_PaintOptions_PaintFlag;

#define sipType_QFlags_0100QCamera_Feature sipExportedTypes_QtMultimedia[31]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QFlags_0100QCamera_Feature;

#define sipType_QList_0100QMediaFormat_VideoCodec sipExportedTypes_QtMultimedia[45]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaFormat_VideoCodec;

#define sipType_QList_0100QMediaFormat_AudioCodec sipExportedTypes_QtMultimedia[43]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaFormat_AudioCodec;

#define sipType_QList_0100QMediaFormat_FileFormat sipExportedTypes_QtMultimedia[44]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaFormat_FileFormat;

#define sipType_QList_0100QImageCapture_FileFormat sipExportedTypes_QtMultimedia[42]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QImageCapture_FileFormat;

#define sipType_QList_0100QAudioFormat_SampleFormat sipExportedTypes_QtMultimedia[38]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudioFormat_SampleFormat;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtMultimedia;
extern sipExportedModuleDef sipModuleAPI_QtMultimedia;
extern sipTypeDef *sipExportedTypes_QtMultimedia[];

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtMultimedia_QtCore[17].it_td

#define sipType_QObject sipImportedTypes_QtMultimedia_QtCore[7].it_td

#define sipType_QIODevice sipImportedTypes_QtMultimedia_QtCore[3].it_td

#define sipType_QByteArray sipImportedTypes_QtMultimedia_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtMultimedia_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtMultimedia_QtCore[14].it_td

#define sipType_QChildEvent sipImportedTypes_QtMultimedia_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtMultimedia_QtCore[4].it_td

#define sipType_QMetaType sipImportedTypes_QtMultimedia_QtCore[5].it_td

#define sipType_QMimeType sipImportedTypes_QtMultimedia_QtCore[6].it_td

#define sipType_QPointF sipImportedTypes_QtMultimedia_QtCore[8].it_td

#define sipType_QRect sipImportedTypes_QtMultimedia_QtCore[9].it_td

#define sipType_QRectF sipImportedTypes_QtMultimedia_QtCore[10].it_td

#define sipType_QSize sipImportedTypes_QtMultimedia_QtCore[11].it_td

#define sipType_QUrl sipImportedTypes_QtMultimedia_QtCore[15].it_td

#define sipType_QVariant sipImportedTypes_QtMultimedia_QtCore[16].it_td

#define sipType_QStringList sipImportedTypes_QtMultimedia_QtCore[13].it_td

#define sipType_QString sipImportedTypes_QtMultimedia_QtCore[12].it_td

#define sipType_std_chrono_milliseconds sipImportedTypes_QtMultimedia_QtCore[18].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimedia_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtMultimedia_QtCore[];

#define sipType_QColor sipImportedTypes_QtMultimedia_QtGui[0].it_td

#define sipType_QImage sipImportedTypes_QtMultimedia_QtGui[1].it_td

#define sipType_QImage_Format sipImportedTypes_QtMultimedia_QtGui[2].it_td

#define sipType_QWindow sipImportedTypes_QtMultimedia_QtGui[6].it_td

#define sipType_QPainter sipImportedTypes_QtMultimedia_QtGui[4].it_td

#define sipType_QScreen sipImportedTypes_QtMultimedia_QtGui[5].it_td

#define sipType_QList_0100QSize sipImportedTypes_QtMultimedia_QtGui[3].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimedia_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtMultimedia_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtMultimedia_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtMultimedia_qt_metacast;

#endif
